@@ -51,14 +51,14 @@ test ${kernel:0:5} = "MINGW" && kernel="MINGW"
 
 compiler="gcc"
 
-qt_version=5.6.2
+qt_version=5.6.3
 zlib_version=1.2.8
 zlib_patchlevel=5
 libogg_version=1.3.2
 libogg_patchlevel=1
 libvorbis_version=1.3.5
 libvorbis_patchlevel=4
-ffmpeg_version=3.2.5
+ffmpeg_version=3.4
 ffmpeg_patchlevel=1
 #libav_version=11.4
 #libav_patchlevel=2
@@ -70,7 +70,7 @@ taglib_version=1.11.1
 chromaprint_version=1.4.2
 chromaprint_patchlevel=1
 mp4v2_version=2.0.0
-mp4v2_patchlevel=5
+mp4v2_patchlevel=6
 
 FLAC_BUILD_OPTION="--enable-debug"
 ID3LIB_BUILD_OPTION="--enable-debug=minimum"
@@ -83,8 +83,8 @@ CMAKE_BUILD_OPTION="-DCMAKE_BUILD_TYPE=RelWithDebInfo"
 #CMAKE_BUILD_OPTION="-DCMAKE_BUILD_TYPE=Debug"
 
 # Uncomment for a LINUX_SELF_CONTAINED build
-#export CC="gcc-4.7"
-#export CXX="g++-4.7"
+#export CC="gcc-4.8"
+#export CXX="g++-4.8"
 #export CFLAGS="-O2 -fPIC"
 #export CXXFLAGS="-O2 -fPIC"
 #AV_BUILD_OPTION="$AV_BUILD_OPTION --enable-pic --extra-ldexeflags=-pie"
@@ -258,7 +258,7 @@ if test "$compiler" = "cross-mingw" && ! test -f mingw.cmake; then
     fi
   done
   cat >mingw.cmake <<EOF
-set(QT_PREFIX /windows/Qt/Qt${qt_version}/${qt_version%.?}/mingw49_32)
+set(QT_PREFIX /windows/Qt/Qt${qt_version}/${qt_version}/mingw49_32)
 
 set(CMAKE_SYSTEM_NAME Windows)
 set(CMAKE_C_COMPILER ${cross_host}-gcc)
@@ -712,6 +712,28 @@ index 0fbb87d..759a9b7 100644
  
 EOF
 
+test -f taglib_CVE-2017-12678.patch ||
+cat >taglib_CVE-2017-12678.patch <<"EOF"
+Index: b/taglib/mpeg/id3v2/id3v2framefactory.cpp
+===================================================================
+--- a/taglib/mpeg/id3v2/id3v2framefactory.cpp
++++ b/taglib/mpeg/id3v2/id3v2framefactory.cpp
+@@ -334,10 +334,11 @@ void FrameFactory::rebuildAggregateFrame
+      tag->frameList("TDAT").size() == 1)
+   {
+     TextIdentificationFrame *tdrc =
+-      static_cast<TextIdentificationFrame *>(tag->frameList("TDRC").front());
++      dynamic_cast<TextIdentificationFrame *>(tag->frameList("TDRC").front());
+     UnknownFrame *tdat = static_cast<UnknownFrame *>(tag->frameList("TDAT").front());
+ 
+-    if(tdrc->fieldList().size() == 1 &&
++    if(tdrc &&
++       tdrc->fieldList().size() == 1 &&
+        tdrc->fieldList().front().size() == 4 &&
+        tdat->data().size() >= 5)
+     {
+EOF
+
 test -f mp4v2_win32.patch ||
 cat >mp4v2_win32.patch <<"EOF"
 diff -ruN mp4v2-2.0.0.orig/GNUmakefile.am mp4v2-2.0.0/GNUmakefile.am
@@ -2114,6 +2136,7 @@ if test "${taglib_version}" = "1.9.1"; then
 fi
 if test "${taglib_version}" = "1.11.1"; then
   patch -p1 <../source/taglib_mp4shwm.patch
+  patch -p1 <../source/taglib_CVE-2017-12678.patch
 fi
 cd ..
 fi
@@ -2550,7 +2573,6 @@ AV_CONFIGURE_OPTIONS="$AV_CONFIGURE_OPTIONS --disable-iconv"
 fi
 AV_CONFIGURE_OPTIONS="$AV_CONFIGURE_OPTIONS $AV_BUILD_OPTION"
 ./configure \
-	--enable-memalign-hack \
 	--disable-shared \
 	--enable-static \
 	--disable-avdevice \
@@ -2729,7 +2751,7 @@ EOF
 BUILDPREFIX=\$(cd ..; pwd)/buildroot/usr/local
 export PKG_CONFIG_PATH=\$BUILDPREFIX/lib/pkgconfig
 # For a LINUX_SELF_CONTAINED build, change BUILD_SHARED_LIBS, WITH_QML to ON and add
-# -G Ninja -DCMAKE_CXX_COMPILER=g++-4.7 -DCMAKE_C_COMPILER=gcc-4.7 -DQT_QMAKE_EXECUTABLE=/opt/Qt5.6.2/5.6/gcc_64/bin/qmake -DLINUX_SELF_CONTAINED=ON -DWITH_READLINE=OFF
+# -G Ninja -DCMAKE_CXX_COMPILER=g++-4.8 -DCMAKE_C_COMPILER=gcc-4.8 -DQT_QMAKE_EXECUTABLE=/opt/Qt5.6.3/5.6.3/gcc_64/bin/qmake -DLINUX_SELF_CONTAINED=ON -DWITH_READLINE=OFF
 cmake -DBUILD_SHARED_LIBS=OFF -DWITH_TAGLIB=OFF -DHAVE_TAGLIB=1 -DTAGLIB_LIBRARIES:STRING="-L\$BUILDPREFIX/lib -ltag -lz" -DTAGLIB_CFLAGS:STRING="-I\$BUILDPREFIX/include/taglib -I\$BUILDPREFIX/include -DTAGLIB_STATIC" -DTAGLIB_VERSION:STRING="${taglib_config_version}" -DWITH_QT5=ON -DWITH_QML=OFF -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL" -DCMAKE_INCLUDE_PATH=\$BUILDPREFIX/include -DCMAKE_LIBRARY_PATH=\$BUILDPREFIX/lib -DCMAKE_PROGRAM_PATH=\$BUILDPREFIX/bin -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON $CMAKE_BUILD_OPTION -DWITH_GCC_PCH=OFF -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. -DWITH_LIBDIR=. -DWITH_PLUGINSDIR=./plugins ../../kid3
 EOF
     fi
