@@ -158,10 +158,11 @@ Frame::TagVersion CliCommand::getTagMaskParameter(int nr,
   if (m_args.size() > nr) {
     const QString& tagStr = m_args.at(nr);
     if (!tagStr.isEmpty() && tagStr.at(0).isDigit()) {
-      if (tagStr.contains(QLatin1Char('1')))
-        tagMask |= 1;
-      if (tagStr.contains(QLatin1Char('2')))
-        tagMask |= 2;
+      FOR_ALL_TAGS(tagNr) {
+        if (tagStr.contains(Frame::tagNumberToString(tagNr))) {
+          tagMask |= Frame::tagVersionFromNumber(tagNr);
+        }
+      }
       if (tagMask == 0)
         tagMask = tagStr.toInt();
     }
@@ -399,7 +400,9 @@ GetCommand::GetCommand(Kid3Cli* processor) :
 void GetCommand::startCommand()
 {
   int numArgs = args().size();
-  QString name = numArgs > 1 ? args().at(1) : QLatin1String("all");
+  QString name = numArgs > 1
+      ? Frame::getNameForTranslatedFrameName(args().at(1))
+      : QLatin1String("all");
   Frame::TagVersion tagMask = getTagMaskParameter(2);
   if (name == QLatin1String("all")) {
     cli()->writeFileInformation(tagMask);
@@ -426,13 +429,15 @@ void SetCommand::startCommand()
 {
   int numArgs = args().size();
   if (numArgs > 2) {
-    const QString& name = args().at(1);
+    QString name = Frame::getNameForTranslatedFrameName(args().at(1));
     const QString& value = args().at(2);
     Frame::TagVersion tagMask = getTagMaskParameter(3);
     if (cli()->app()->setFrame(tagMask, name, value)) {
-      cli()->updateSelectedFiles();
-      cli()->updateSelection();
-    } else {
+      if (!name.endsWith(QLatin1String(".selected"))) {
+        cli()->updateSelectedFiles();
+        cli()->updateSelection();
+      }
+    } else if (!value.isEmpty()) {
       setError(tr("Could not set \"%1\" for %2").arg(value).arg(name));
     }
   } else {
@@ -455,12 +460,10 @@ void RevertCommand::startCommand()
 
 ImportCommand::ImportCommand(Kid3Cli* processor) :
   CliCommand(processor, QLatin1String("import"),
-             tr("Import from file or clipboard"),
+             tr("Import from file"),
              QLatin1String("P S [T]\nP S = ") +
              tr("File path") + QLatin1Char(' ') + tr("Format name") +
-             QLatin1String(" | ") +
-             QLatin1String("clipboard ") + tr("Format name") +
-             QLatin1String("\n    | tags ") + tr("Source") + QLatin1Char(' ') +
+             QLatin1String(" | tags ") + tr("Source") + QLatin1Char(' ') +
              tr("Extraction"))
 {
 }
@@ -636,7 +639,7 @@ void AlbumArtCommand::onDownloadFinished(
 
 ExportCommand::ExportCommand(Kid3Cli* processor) :
   CliCommand(processor, QLatin1String("export"),
-             tr("Export to file or clipboard"),
+             tr("Export to file"),
              QLatin1String("P S [T]\nS = ") + tr("Format name"))
 {
 }
@@ -873,14 +876,14 @@ void FilterCommand::startCommand()
 
 void FilterCommand::connectResultSignal()
 {
-  connect(cli()->app(), SIGNAL(fileFiltered(int,QString)),
+  connect(cli()->app(), SIGNAL(fileFiltered(int,QString,int,int)),
           this, SLOT(onFileFiltered(int,QString)));
 }
 
 void FilterCommand::disconnectResultSignal()
 {
   cli()->app()->abortFilter();
-  disconnect(cli()->app(), SIGNAL(fileFiltered(int,QString)),
+  disconnect(cli()->app(), SIGNAL(fileFiltered(int,QString,int,int)),
              this, SLOT(onFileFiltered(int,QString)));
 }
 
