@@ -234,12 +234,13 @@ QStringList splitArgs(const QString& str)
  * Constructor.
  * @param app application context
  * @param io I/O handler
+ * @param args command line arguments
  * @param parent parent object
  */
 Kid3Cli::Kid3Cli(Kid3Application* app,
-                 AbstractCliIO* io, QObject* parent) :
+                 AbstractCliIO* io, const QStringList& args, QObject* parent) :
   AbstractCli(io, parent),
-  m_app(app),
+  m_app(app), m_args(args),
   m_tagMask(Frame::TagV2V1), m_timeoutMs(0), m_fileNameChanged(false)
 {
   m_cmds << new HelpCommand(this)
@@ -281,6 +282,8 @@ Kid3Cli::Kid3Cli(Kid3Application* app,
           this, SLOT(updateSelectedFiles()));
   connect(m_app, SIGNAL(selectedFilesUpdated()),
           this, SLOT(updateSelection()));
+  connect(m_app, SIGNAL(selectedFilesChanged(QItemSelection,QItemSelection)),
+          this, SLOT(updateSelection()));
 #ifdef HAVE_READLINE
   m_completer = new Kid3CliCompleter(m_cmds);
   m_completer->install();
@@ -333,8 +336,17 @@ void Kid3Cli::writeHelp(const QString& cmdName)
     writeLine(tr("Parameter"));
     writeLine(QLatin1String("  P = ") + tr("File path"));
     writeLine(QLatin1String("  U = ") + tr("URL"));
+    QString tagNumbersStr;
+    FOR_ALL_TAGS(tagNr) {
+      if (!tagNumbersStr.isEmpty()) {
+        tagNumbersStr += QLatin1Char('|');
+      }
+      tagNumbersStr += QLatin1String(" \"");
+      tagNumbersStr += Frame::tagNumberToString(tagNr);
+      tagNumbersStr += QLatin1String("\" ");
+    }
     writeLine(QLatin1String("  T = ") + tr("Tag numbers") +
-              QLatin1String(" \"1\" | \"2\" | \"12\""));
+              tagNumbersStr + QLatin1String("| \"12\" | ..."));
     writeLine(QLatin1String("  N = ") + tr("Frame name") +
               QLatin1String(" \"album\" | \"album artist\" | \"arranger\" | "
                             "\"artist\" | ..."));
@@ -635,6 +647,11 @@ void Kid3Cli::printFileProxyModel(const FileProxyModel* model,
  */
 void Kid3Cli::readLine(const QString& line)
 {
+  if (line.isNull()) {
+    // Terminate if EOF is received.
+    terminate();
+    return;
+  }
   flushStandardOutput();
   CliCommand* cmd = commandForArgs(line);
   if (cmd) {
@@ -686,7 +703,7 @@ void Kid3Cli::onArgCommandFinished() {
 
 bool Kid3Cli::parseOptions()
 {
-  QStringList args = QCoreApplication::arguments().mid(1);
+  QStringList args = m_args.mid(1);
   QStringList paths;
   bool isCommand = false;
   foreach (const QString& arg, args) {
