@@ -24,7 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QApplication>
+#include <QCoreApplication>
 #include <QLibraryInfo>
 #include <QDir>
 #include <QTimer>
@@ -50,24 +50,31 @@ int _CRT_glob = 0;
  */
 int main(int argc, char* argv[])
 {
-  QApplication app(argc, argv);
+  QCoreApplication app(argc, argv);
   app.setApplicationName(QLatin1String("Kid3"));
 
   Utils::loadTranslation();
 
 #ifdef Q_OS_MAC
- QDir dir(QApplication::applicationDirPath());
- dir.cdUp();
- dir.cd(QLatin1String("PlugIns"));
- QApplication::setLibraryPaths(QStringList(dir.absolutePath()));
+  QDir dir(QCoreApplication::applicationDirPath());
+  dir.cdUp();
+  dir.cd(QLatin1String("PlugIns"));
+  QCoreApplication::setLibraryPaths(QStringList(dir.absolutePath()));
 #endif
 
- ICorePlatformTools* platformTools = new CorePlatformTools;
- Kid3Application* kid3App = new Kid3Application(platformTools);
- Kid3Cli kid3cli(kid3App, new StandardIOHandler("kid3-cli> "));
- QTimer::singleShot(0, &kid3cli, SLOT(execute()));
- int rc = app.exec();
- delete kid3App;
- delete platformTools;
- return rc;
+  QStringList args = QCoreApplication::arguments();
+  if (args.size() > 1 && args.at(1) == QLatin1String("--portable")) {
+    args.removeAt(1);
+    qputenv("KID3_CONFIG_FILE",
+            QCoreApplication::applicationDirPath().toLatin1() + "/kid3.ini");
+  }
+
+  ICorePlatformTools* platformTools = new CorePlatformTools;
+  Kid3Application* kid3App = new Kid3Application(platformTools);
+  Kid3Cli kid3cli(kid3App, new StandardIOHandler("kid3-cli> "), args);
+  QTimer::singleShot(0, &kid3cli, SLOT(execute()));
+  int rc = app.exec();
+  delete kid3App;
+  delete platformTools;
+  return rc;
 }
