@@ -85,6 +85,13 @@ bool Kid3KdeApplication::notify(QObject* receiver, QEvent* event)
  */
 int main(int argc, char* argv[])
 {
+#if QT_VERSION >= 0x050100
+  // Enable support for high resolution "@2x" images
+  QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
+#if QT_VERSION >= 0x050600
+  QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
   Kid3KdeApplication app(argc, argv);
   KAboutData aboutData(QStringLiteral("kid3"),
                        QStringLiteral("Kid3"),
