@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2014  Urs Fleisch
+ * Copyright (C) 2003-2017  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -37,7 +37,6 @@
 #include <QStatusBar>
 #include <QSessionManager>
 #include "config.h"
-#include "qtcompatmac.h"
 #include "recentfilesmenu.h"
 #include "shortcutsmodel.h"
 #include "mainwindowconfig.h"
@@ -48,6 +47,7 @@
 #include "guiconfig.h"
 #include "tagconfig.h"
 #include "fileconfig.h"
+#include "useractionsconfig.h"
 #include "contexthelp.h"
 #include "serverimporter.h"
 #include "servertrackimporter.h"
@@ -65,6 +65,7 @@ Kid3MainWindow::Kid3MainWindow(IPlatformTools* platformTools,
                                Kid3Application* app, QWidget* parent) :
   QMainWindow(parent),
   BaseMainWindow(this, platformTools, app),
+  m_platformTools(platformTools),
   m_shortcutsModel(new ShortcutsModel(this))
 {
 #if !defined Q_OS_WIN32 && defined CFG_DATAROOTDIR
@@ -74,7 +75,7 @@ Kid3MainWindow::Kid3MainWindow(IPlatformTools* platformTools,
   QPixmap icon;
   if (icon.load(dataRootDir +
 #ifndef Q_OS_MAC
-                QLatin1String("/icons/hicolor/48x48/apps/kid3-qt.png")
+                QLatin1String("/icons/hicolor/128x128/apps/kid3-qt.png")
 #else
                 QLatin1String("/kid3.png")
 #endif
@@ -117,7 +118,8 @@ void Kid3MainWindow::initActions()
   fileOpen->setStatusTip(tr("Open files"));
   fileOpen->setText(tr("&Open..."));
   fileOpen->setShortcut(QKeySequence::Open);
-  fileOpen->setIcon(QCM_QIcon_fromTheme("document-open"));
+  fileOpen->setIcon(QIcon::fromTheme(QLatin1String("document-open"),
+      QIcon(QLatin1String(":/images/document-open.png"))));
   fileOpen->setObjectName(QLatin1String("file_open"));
   m_shortcutsModel->registerAction(fileOpen, menuTitle);
   connect(fileOpen, SIGNAL(triggered()),
@@ -130,14 +132,17 @@ void Kid3MainWindow::initActions()
           this, SLOT(slotFileOpenRecentDirectory(QString)));
   m_fileOpenRecent->setStatusTip(tr("Opens a recently used directory"));
   m_fileOpenRecent->setTitle(tr("Open &Recent"));
-  m_fileOpenRecent->setIcon(QCM_QIcon_fromTheme("document-open-recent"));
+  m_fileOpenRecent->setIcon(QIcon::fromTheme(
+      QLatin1String("document-open-recent"),
+      QIcon(QLatin1String(":/images/document-open-recent.png"))));
   fileMenu->addMenu(m_fileOpenRecent);
 
   QAction* fileOpenDirectory = new QAction(this);
   fileOpenDirectory->setStatusTip(tr("Opens a directory"));
   fileOpenDirectory->setText(tr("O&pen Directory..."));
   fileOpenDirectory->setShortcut(Qt::CTRL + Qt::Key_D);
-  fileOpenDirectory->setIcon(QCM_QIcon_fromTheme("document-open"));
+  fileOpenDirectory->setIcon(QIcon::fromTheme(QLatin1String("document-open"),
+      QIcon(QLatin1String(":/images/document-open.png"))));
   fileOpenDirectory->setObjectName(QLatin1String("open_directory"));
   m_shortcutsModel->registerAction(fileOpenDirectory, menuTitle);
   connect(fileOpenDirectory, SIGNAL(triggered()),
@@ -149,7 +154,8 @@ void Kid3MainWindow::initActions()
   fileSave->setStatusTip(tr("Saves the changed files"));
   fileSave->setText(tr("&Save"));
   fileSave->setShortcut(QKeySequence::Save);
-  fileSave->setIcon(QCM_QIcon_fromTheme("document-save"));
+  fileSave->setIcon(QIcon::fromTheme(QLatin1String("document-save"),
+      QIcon(QLatin1String(":/images/document-save.png"))));
   fileSave->setObjectName(QLatin1String("file_save"));
   m_shortcutsModel->registerAction(fileSave, menuTitle);
   connect(fileSave, SIGNAL(triggered()),
@@ -162,7 +168,8 @@ void Kid3MainWindow::initActions()
       tr("Reverts the changes of all or the selected files"));
   fileRevert->setText(tr("Re&vert"));
   fileRevert->setShortcut(QKeySequence::Undo);
-  fileRevert->setIcon(QCM_QIcon_fromTheme("document-revert"));
+  fileRevert->setIcon(QIcon::fromTheme(QLatin1String("document-revert"),
+      QIcon(QLatin1String(":/images/document-revert.png"))));
   fileRevert->setObjectName(QLatin1String("file_revert"));
   m_shortcutsModel->registerAction(fileRevert, menuTitle);
   connect(fileRevert, SIGNAL(triggered()),
@@ -175,7 +182,8 @@ void Kid3MainWindow::initActions()
   fileImport->setData(-1);
   fileImport->setStatusTip(tr("Import from file or clipboard"));
   fileImport->setText(tr("&Import..."));
-  fileImport->setIcon(QCM_QIcon_fromTheme("document-import"));
+  fileImport->setIcon(QIcon::fromTheme(QLatin1String("document-import"),
+      QIcon(QLatin1String(":/images/document-import.png"))));
   fileImport->setObjectName(QLatin1String("import"));
   m_shortcutsModel->registerAction(fileImport, menuTitle);
   connect(fileImport, SIGNAL(triggered()),
@@ -185,7 +193,8 @@ void Kid3MainWindow::initActions()
   int importerIdx = 0;
   foreach (const ServerImporter* si, app()->getServerImporters()) {
     QString serverName(QCoreApplication::translate("@default", si->name()));
-    QString actionName = QString::fromLatin1(si->name()).toLower().remove(QLatin1Char(' '));
+    QString actionName = QString::fromLatin1(
+          si->name()).toLower().remove(QLatin1Char(' '));
     int dotPos = actionName.indexOf(QLatin1Char('.'));
     if (dotPos != -1)
       actionName.truncate(dotPos);
@@ -204,7 +213,8 @@ void Kid3MainWindow::initActions()
 
   foreach (const ServerTrackImporter* si, app()->getServerTrackImporters()) {
     QString serverName(QCoreApplication::translate("@default", si->name()));
-    QString actionName = QString::fromLatin1(si->name()).toLower().remove(QLatin1Char(' '));
+    QString actionName = QString::fromLatin1(
+          si->name()).toLower().remove(QLatin1Char(' '));
     int dotPos = actionName.indexOf(QLatin1Char('.'));
     if (dotPos != -1)
       actionName.truncate(dotPos);
@@ -243,7 +253,8 @@ void Kid3MainWindow::initActions()
   QAction* fileExport = new QAction(this);
   fileExport->setStatusTip(tr("Export to file or clipboard"));
   fileExport->setText(tr("&Export..."));
-  fileExport->setIcon(QCM_QIcon_fromTheme("document-export"));
+  fileExport->setIcon(QIcon::fromTheme(QLatin1String("document-export"),
+      QIcon(QLatin1String(":/images/document-export.png"))));
   fileExport->setObjectName(QLatin1String("export"));
   m_shortcutsModel->registerAction(fileExport, menuTitle);
   connect(fileExport, SIGNAL(triggered()),
@@ -253,13 +264,9 @@ void Kid3MainWindow::initActions()
   QAction* fileCreatePlaylist = new QAction(this);
   fileCreatePlaylist->setStatusTip(tr("Create M3U Playlist"));
   fileCreatePlaylist->setText(tr("&Create Playlist..."));
-#if QT_VERSION >= 0x040600
   fileCreatePlaylist->setIcon(
         QIcon::fromTheme(QLatin1String("format-justify-fill"),
             QIcon(QLatin1String(":/images/view-media-playlist.png"))));
-#else
-  fileCreatePlaylist->setIcon(QIcon(QLatin1String(":/images/view-media-playlist.png")));
-#endif
   fileCreatePlaylist->setObjectName(QLatin1String("create_playlist"));
   m_shortcutsModel->registerAction(fileCreatePlaylist, menuTitle);
   connect(fileCreatePlaylist, SIGNAL(triggered()),
@@ -272,10 +279,9 @@ void Kid3MainWindow::initActions()
   fileQuit->setStatusTip(tr("Quits the application"));
   fileQuit->setText(tr("&Quit"));
   fileQuit->setShortcut(Qt::CTRL + Qt::Key_Q);
-  fileQuit->setIcon(QCM_QIcon_fromTheme("application-exit"));
-#if QT_VERSION >= 0x040200
+  fileQuit->setIcon(QIcon::fromTheme(QLatin1String("application-exit"),
+      QIcon(QLatin1String(":/images/application-exit.png"))));
   fileQuit->setMenuRole(QAction::QuitRole);
-#endif
   fileQuit->setObjectName(QLatin1String("file_quit"));
   m_shortcutsModel->registerAction(fileQuit, menuTitle);
   connect(fileQuit, SIGNAL(triggered()),
@@ -288,7 +294,8 @@ void Kid3MainWindow::initActions()
   editSelectAll->setStatusTip(tr("Select all files"));
   editSelectAll->setText(tr("Select &All"));
   editSelectAll->setShortcut(Qt::ALT + Qt::Key_A);
-  editSelectAll->setIcon(QCM_QIcon_fromTheme("edit-select-all"));
+  editSelectAll->setIcon(QIcon::fromTheme(QLatin1String("edit-select-all"),
+      QIcon(QLatin1String(":/images/edit-select-all.png"))));
 #if defined Q_OS_MAC && QT_VERSION == 0x050400
   // Workaround for QTBUG-43471 from QTBUG-39934
   editSelectAll->setMenuRole(QAction::NoRole);
@@ -310,7 +317,8 @@ void Kid3MainWindow::initActions()
   editMenu->addAction(editDeselect);
 
   QAction* editSelectAllInDir = new QAction(this);
-  editSelectAllInDir->setStatusTip(tr("Select all files in the current directory"));
+  editSelectAllInDir->setStatusTip(
+        tr("Select all files in the current directory"));
   editSelectAllInDir->setText(tr("Select All in &Directory"));
   editSelectAllInDir->setObjectName(QLatin1String("select_all_in_directory"));
   m_shortcutsModel->registerAction(editSelectAllInDir, menuTitle);
@@ -322,7 +330,8 @@ void Kid3MainWindow::initActions()
   editPreviousFile->setStatusTip(tr("Select previous file"));
   editPreviousFile->setText(tr("&Previous File"));
   editPreviousFile->setShortcut(Qt::ALT + Qt::Key_Up);
-  editPreviousFile->setIcon(QCM_QIcon_fromTheme("go-previous"));
+  editPreviousFile->setIcon(QIcon::fromTheme(QLatin1String("go-previous"),
+      QIcon(QLatin1String(":/images/go-previous.png"))));
   editPreviousFile->setObjectName(QLatin1String("previous_file"));
   m_shortcutsModel->registerAction(editPreviousFile, menuTitle);
   connect(editPreviousFile, SIGNAL(triggered()),
@@ -334,7 +343,8 @@ void Kid3MainWindow::initActions()
   editNextFile->setStatusTip(tr("Select next file"));
   editNextFile->setText(tr("&Next File"));
   editNextFile->setShortcut(Qt::ALT + Qt::Key_Down);
-  editNextFile->setIcon(QCM_QIcon_fromTheme("go-next"));
+  editNextFile->setIcon(QIcon::fromTheme(QLatin1String("go-next"),
+      QIcon(QLatin1String(":/images/go-next.png"))));
   editNextFile->setObjectName(QLatin1String("next_file"));
   m_shortcutsModel->registerAction(editNextFile, menuTitle);
   connect(editNextFile, SIGNAL(triggered()),
@@ -348,7 +358,8 @@ void Kid3MainWindow::initActions()
   editFind->setText(tr("&Find..."));
   editFind->setShortcut(QKeySequence::Find);
 #ifndef Q_OS_MAC
-  editFind->setIcon(QCM_QIcon_fromTheme("edit-find"));
+  editFind->setIcon(QIcon::fromTheme(QLatin1String("edit-find"),
+      QIcon(QLatin1String(":/images/edit-find.png"))));
 #endif
   editFind->setObjectName(QLatin1String("edit_find"));
   m_shortcutsModel->registerAction(editFind, menuTitle);
@@ -361,7 +372,8 @@ void Kid3MainWindow::initActions()
   editReplace->setText(tr("&Replace..."));
   editReplace->setShortcut(QKeySequence::Replace);
 #ifndef Q_OS_MAC
-  editReplace->setIcon(QCM_QIcon_fromTheme("edit-find-replace"));
+  editReplace->setIcon(QIcon::fromTheme(QLatin1String("edit-find-replace"),
+      QIcon(QLatin1String(":/images/edit-find-replace.png"))));
 #endif
   editReplace->setObjectName(QLatin1String("edit_replace"));
   m_shortcutsModel->registerAction(editReplace, menuTitle);
@@ -374,7 +386,8 @@ void Kid3MainWindow::initActions()
   QAction* toolsApplyFilenameFormat = new QAction(this);
   toolsApplyFilenameFormat->setStatusTip(tr("Apply Filename Format"));
   toolsApplyFilenameFormat->setText(tr("Apply &Filename Format"));
-  toolsApplyFilenameFormat->setObjectName(QLatin1String("apply_filename_format"));
+  toolsApplyFilenameFormat->setObjectName(
+        QLatin1String("apply_filename_format"));
   m_shortcutsModel->registerAction(toolsApplyFilenameFormat, menuTitle);
   connect(toolsApplyFilenameFormat, SIGNAL(triggered()),
     app(), SLOT(applyFilenameFormat()));
@@ -511,13 +524,11 @@ void Kid3MainWindow::initActions()
   QAction* settingsConfigure = new QAction(this);
   settingsConfigure->setStatusTip(tr("Configure Kid3"));
   settingsConfigure->setText(tr("&Configure Kid3..."));
-  settingsConfigure->setIcon(QCM_QIcon_fromTheme("preferences-system"));
-#if QT_VERSION >= 0x040600
+  settingsConfigure->setIcon(QIcon::fromTheme(
+      QLatin1String("preferences-system"),
+      QIcon(QLatin1String(":/images/preferences-system.png"))));
   settingsConfigure->setShortcut(QKeySequence::Preferences);
-#endif
-#if QT_VERSION >= 0x040200
   settingsConfigure->setMenuRole(QAction::PreferencesRole);
-#endif
   settingsConfigure->setObjectName(QLatin1String("options_configure"));
   m_shortcutsModel->registerAction(settingsConfigure, menuTitle);
   connect(settingsConfigure, SIGNAL(triggered()),
@@ -531,7 +542,8 @@ void Kid3MainWindow::initActions()
   QAction* helpHandbook = new QAction(this);
   helpHandbook->setStatusTip(tr("Kid3 Handbook"));
   helpHandbook->setText(tr("Kid3 &Handbook"));
-  helpHandbook->setIcon(QCM_QIcon_fromTheme("help-contents"));
+  helpHandbook->setIcon(QIcon::fromTheme(QLatin1String("help-contents"),
+      QIcon(QLatin1String(":/images/help-contents.png"))));
   helpHandbook->setShortcut(QKeySequence::HelpContents);
   helpHandbook->setObjectName(QLatin1String("help_contents"));
   m_shortcutsModel->registerAction(helpHandbook, menuTitle);
@@ -543,11 +555,10 @@ void Kid3MainWindow::initActions()
   helpAbout->setStatusTip(tr("About Kid3"));
   helpAbout->setText(tr("&About Kid3"));
 #ifndef Q_OS_MAC
-  helpAbout->setIcon(QCM_QIcon_fromTheme("help-about"));
+  helpAbout->setIcon(QIcon::fromTheme(QLatin1String("help-about"),
+      QIcon(QLatin1String(":/images/help-about.png"))));
 #endif
-#if QT_VERSION >= 0x040200
   helpAbout->setMenuRole(QAction::AboutRole);
-#endif
   helpAbout->setObjectName(QLatin1String("help_about_app"));
   m_shortcutsModel->registerAction(helpAbout, menuTitle);
   connect(helpAbout, SIGNAL(triggered()),
@@ -557,9 +568,7 @@ void Kid3MainWindow::initActions()
   QAction* helpAboutQt = new QAction(this);
   helpAboutQt->setStatusTip(tr("About Qt"));
   helpAboutQt->setText(tr("About &Qt"));
-#if QT_VERSION >= 0x040200
   helpAboutQt->setMenuRole(QAction::AboutQtRole);
-#endif
   helpAboutQt->setObjectName(QLatin1String("help_about_qt"));
   m_shortcutsModel->registerAction(helpAboutQt, menuTitle);
   connect(helpAboutQt, SIGNAL(triggered()),
@@ -571,6 +580,16 @@ void Kid3MainWindow::initActions()
   updateWindowCaption();
 
   initFormActions();
+
+  FileList* fileList = form()->getFileList();
+  connect(fileList, SIGNAL(userActionAdded(QString,QAction*)),
+          this, SLOT(onUserActionAdded(QString,QAction*)));
+  connect(fileList, SIGNAL(userActionRemoved(QString,QAction*)),
+          this, SLOT(onUserActionRemoved(QString,QAction*)));
+  fileList->initUserActions();
+  const UserActionsConfig& userActionsCfg = UserActionsConfig::instance();
+  connect(&userActionsCfg, SIGNAL(contextMenuCommandsChanged()),
+          fileList, SLOT(initUserActions()));
 }
 
 /**
@@ -579,28 +598,50 @@ void Kid3MainWindow::initActions()
 void Kid3MainWindow::initFormActions()
 {
   QString ctx(tr("Filename"));
-  initAction(tr("From Tag 1"), QLatin1String("filename_from_v1"), form(), SLOT(fnFromID3V1()), ctx);
-  initAction(tr("From Tag 2"), QLatin1String("filename_from_v2"), form(), SLOT(fnFromID3V2()), ctx);
-  initAction(tr("Focus"), QLatin1String("filename_focus"), form(), SLOT(setFocusFilename()), ctx);
-  ctx = tr("Tag 1");
-  initAction(tr("From Filename"), QLatin1String("v1_from_filename"), app(), SLOT(getTagsFromFilenameV1()), ctx);
-  initAction(tr("From Tag 2"), QLatin1String("v1_from_v2"), app(), SLOT(copyV2ToV1()), ctx);
-  initAction(tr("Copy"), QLatin1String("v1_copy"), app(), SLOT(copyTagsV1()), ctx);
-  initAction(tr("Paste"), QLatin1String("v1_paste"), app(), SLOT(pasteTagsV1()), ctx);
-  initAction(tr("Remove"), QLatin1String("v1_remove"), app(), SLOT(removeTagsV1()), ctx);
-  initAction(tr("Focus"), QLatin1String("v1_focus"), form(), SLOT(setFocusV1()), ctx);
-  ctx = tr("Tag 2");
-  initAction(tr("From Filename"), QLatin1String("v2_from_filename"), app(), SLOT(getTagsFromFilenameV2()), ctx);
-  initAction(tr("From Tag 1"), QLatin1String("v2_from_v1"), app(), SLOT(copyV1ToV2()), ctx);
-  initAction(tr("Copy"), QLatin1String("v2_copy"), app(), SLOT(copyTagsV2()), ctx);
-  initAction(tr("Paste"), QLatin1String("v2_paste"), app(), SLOT(pasteTagsV2()), ctx);
-  initAction(tr("Remove"), QLatin1String("v2_remove"), app(), SLOT(removeTagsV2()), ctx);
-  initAction(tr("Edit"), QLatin1String("frames_edit"), form(), SLOT(editFrame()), ctx);
-  initAction(tr("Add"), QLatin1String("frames_add"), form(), SLOT(addFrame()), ctx);
-  initAction(tr("Delete"), QLatin1String("frames_delete"), form(), SLOT(deleteFrame()), ctx);
-  initAction(tr("Focus"), QLatin1String("v2_focus"), form(), SLOT(setFocusV2()), ctx);
+  FOR_ALL_TAGS(tagNr) {
+    QString tagStr = Frame::tagNumberToString(tagNr);
+    initAction(tr("From Tag %1").arg(tagStr),
+               QLatin1String("filename_from_v") + tagStr,
+               app()->tag(tagNr), SLOT(getFilenameFromTags()), ctx);
+  }
+  initAction(tr("Focus"), QLatin1String("filename_focus"),
+             form(), SLOT(setFocusFilename()), ctx);
+  FOR_ALL_TAGS(tagNr) {
+    Frame::TagNumber otherTagNr = tagNr == Frame::Tag_1 ? Frame::Tag_2 :
+          tagNr == Frame::Tag_2 ? Frame::Tag_1 : Frame::Tag_NumValues;
+    QString tagStr = Frame::tagNumberToString(tagNr);
+    Kid3ApplicationTagContext* appTag = app()->tag(tagNr);
+    Kid3FormTagContext* formTag = form()->tag(tagNr);
+    ctx = tr("Tag %1").arg(tagStr);
+    tagStr = QLatin1Char('v') + tagStr + QLatin1Char('_');
+    initAction(tr("From Filename"), tagStr + QLatin1String("from_filename"),
+               appTag, SLOT(getTagsFromFilename()), ctx);
+    if (otherTagNr < Frame::Tag_NumValues) {
+      QString otherTagStr = Frame::tagNumberToString(otherTagNr);
+      initAction(tr("From Tag %1").arg(otherTagStr),
+                 tagStr + QLatin1String("from_v") + otherTagStr,
+                 appTag, SLOT(copyToOtherTag()), ctx);
+    }
+    initAction(tr("Copy"), tagStr + QLatin1String("copy"),
+               appTag, SLOT(copyTags()), ctx);
+    initAction(tr("Paste"), tagStr + QLatin1String("paste"),
+               appTag, SLOT(pasteTags()), ctx);
+    initAction(tr("Remove"), tagStr + QLatin1String("remove"),
+               appTag, SLOT(removeTags()), ctx);
+    if (tagNr != Frame::Tag_Id3v1) {
+      initAction(tr("Edit"), tagStr + QLatin1String("frames_edit"),
+                 appTag, SLOT(editFrame()), ctx);
+      initAction(tr("Add"), tagStr + QLatin1String("frames_add"),
+                 appTag, SLOT(addFrame()), ctx);
+      initAction(tr("Delete"), tagStr + QLatin1String("frames_delete"),
+                 appTag, SLOT(deleteFrame()), ctx);
+    }
+    initAction(tr("Focus"), tagStr + QLatin1String("focus"),
+               formTag, SLOT(setFocusTag()), ctx);
+  }
   ctx = tr("File List");
-  initAction(tr("Focus"), QLatin1String("filelist_focus"), form(), SLOT(setFocusFileList()), ctx);
+  initAction(tr("Focus"), QLatin1String("filelist_focus"),
+             form(), SLOT(setFocusFileList()), ctx);
   QAction* renameAction = new QAction(tr("&Rename"), this);
   renameAction->setObjectName(QLatin1String("filelist_rename"));
   renameAction->setShortcut(QKeySequence(Qt::Key_F2));
@@ -616,7 +657,8 @@ void Kid3MainWindow::initFormActions()
   form()->getFileList()->setDeleteAction(deleteAction);
   m_shortcutsModel->registerAction(deleteAction, ctx);
   ctx = tr("Directory List");
-  initAction(tr("Focus"), QLatin1String("dirlist_focus"), form(), SLOT(setFocusDirList()), ctx);
+  initAction(tr("Focus"), QLatin1String("dirlist_focus"),
+             form(), SLOT(setFocusDirList()), ctx);
 }
 
 /**
@@ -798,8 +840,8 @@ void Kid3MainWindow::slotHelpAbout()
     QLatin1String("<br/><br/>(c) 2003-" RELEASE_YEAR
     " <a href=\"mailto:ufleisch@users.sourceforge.net\">Urs Fleisch</a>"
     "<br/><br/>"
-    "<a href=\"http://kid3.sourceforge.net/\">http://kid3.sourceforge.net</a><br/>") +
-    tr("License") +
+    "<a href=\"http://kid3.sourceforge.net/\">http://kid3.sourceforge.net</a>"
+    "<br/>") + tr("License") +
     QLatin1String(": <a href=\"http://www.gnu.org/licenses/licenses.html#GPL\">"
     "GNU General Public License</a><br/> "));
 }
@@ -818,7 +860,8 @@ void Kid3MainWindow::slotHelpAboutQt()
 void Kid3MainWindow::slotSettingsConfigure()
 {
   QString caption(tr("Configure - Kid3"));
-  ConfigDialog* dialog = new ConfigDialog(this, caption, m_shortcutsModel);
+  ConfigDialog* dialog = new ConfigDialog(m_platformTools, this, caption,
+                                          m_shortcutsModel);
   dialog->setConfig();
   if (dialog->exec() == QDialog::Accepted) {
     dialog->getConfig();
@@ -849,3 +892,28 @@ void Kid3MainWindow::onCommitDataRequest(QSessionManager& manager)
     }
   }
 }
+
+/**
+ * Add user action to shortcuts.
+ * @param name name of action
+ * @param action action to add
+ */
+void Kid3MainWindow::onUserActionAdded(const QString& name, QAction* action)
+{
+  action->setObjectName(name);
+  action->setShortcutContext(Qt::ApplicationShortcut);
+  m_shortcutsModel->registerAction(action, tr("User Actions"));
+  addAction(action);
+}
+
+/**
+ * Remove user action from shortcuts.
+ * @param name name of action
+ * @param action action to remove
+ */
+void Kid3MainWindow::onUserActionRemoved(const QString& name, QAction* action)
+{
+  Q_UNUSED(name)
+  m_shortcutsModel->unregisterAction(action, tr("User Actions"));
+  removeAction(action);
+}
