@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 29 Dec 2011
  *
- * Copyright (C) 2011-2013  Urs Fleisch
+ * Copyright (C) 2011-2017  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -284,6 +284,34 @@ void ShortcutsModel::registerAction(QAction* action, const QString& context)
   }
 }
 
+/**
+ * Unregister an action.
+ *
+ * @param action action to be removed from model
+ * @param context context of action
+ */
+void ShortcutsModel::unregisterAction(QAction* action, const QString& context)
+{
+  for (QList<ShortcutGroup>::iterator git = m_shortcutGroups.begin();
+       git != m_shortcutGroups.end();
+       ++git) {
+    if (git->context() == context) {
+      for (ShortcutGroup::iterator iit = git->begin();
+           iit != git->end();
+           ++iit) {
+        if (iit->action() == action) {
+          git->erase(iit);
+          break;
+        }
+      }
+      if (git->isEmpty()) {
+        m_shortcutGroups.erase(git);
+      }
+      break;
+    }
+  }
+}
+
 /**
  * Assign the shortcuts which have been changed to their actions.
  *
@@ -328,9 +356,7 @@ void ShortcutsModel::discardChangedShortcuts()
  */
 void ShortcutsModel::clearShortcuts()
 {
-#if QT_VERSION >= 0x040600
   beginResetModel();
-#endif
   for (QList<ShortcutGroup>::iterator git = m_shortcutGroups.begin();
        git != m_shortcutGroups.end();
        ++git) {
@@ -340,11 +366,7 @@ void ShortcutsModel::clearShortcuts()
       iit->clearCustomShortcut();
     }
   }
-#if QT_VERSION >= 0x040600
   endResetModel();
-#else
-  reset();
-#endif
 }
 
 /**
