@@ -36,7 +36,7 @@ int BatchImportConfig::s_index = -1;
  */
 BatchImportConfig::BatchImportConfig() :
   StoredConfig<BatchImportConfig>(QLatin1String("BatchImport")),
-  m_importDest(TrackData::TagV2), m_profileIdx(0)
+  m_importDest(Frame::TagV2), m_profileIdx(0)
 {
   /**
    * Preset profile expressions.
@@ -48,10 +48,10 @@ BatchImportConfig::BatchImportConfig() :
     QLatin1String("Cover Art") <<
     QLatin1String("Custom Profile");
   m_profileSources <<
-    QLatin1String("MusicBrainz Release:75:SAC;Discogs:75:SA;Amazon:75:SAC;gnudb.org:75:S;TrackType.org:75:S") <<
+    QLatin1String("MusicBrainz Release:75:SAC;Discogs:75:SAC;Amazon:75:SAC;gnudb.org:75:S;TrackType.org:75:S") <<
     QLatin1String("MusicBrainz Release:75:SAC") <<
-    QLatin1String("Discogs:75:SA") <<
-    QLatin1String("Amazon:75:C;MusicBrainz Release:75:C") <<
+    QLatin1String("Discogs:75:SAC") <<
+    QLatin1String("Amazon:75:C;Discogs:75:C;MusicBrainz Release:75:C") <<
     QLatin1String("");
 }
 
@@ -87,7 +87,7 @@ void BatchImportConfig::readFromConfig(ISettings* config)
 {
   QStringList names, sources;
   config->beginGroup(m_group);
-  m_importDest = TrackData::tagVersionCast(
+  m_importDest = Frame::tagVersionCast(
         config->value(QLatin1String("ImportDestination"), m_importDest).toInt());
   names = config->value(QLatin1String("ProfileNames"),
                         m_profileNames).toStringList();
@@ -144,3 +144,43 @@ bool BatchImportConfig::getProfileByName(const QString& name,
   }
   return false;
 }
+
+void BatchImportConfig::setImportDest(Frame::TagVersion importDest)
+{
+  if (m_importDest != importDest) {
+    m_importDest = importDest;
+    emit importDestChanged(m_importDest);
+  }
+}
+
+void BatchImportConfig::setWindowGeometry(const QByteArray& windowGeometry)
+{
+  if (m_windowGeometry != windowGeometry) {
+    m_windowGeometry = windowGeometry;
+    emit windowGeometryChanged(m_windowGeometry);
+  }
+}
+
+void BatchImportConfig::setProfileIndex(int profileIdx)
+{
+  if (m_profileIdx != profileIdx) {
+    m_profileIdx = profileIdx;
+    emit profileIndexChanged(m_profileIdx);
+  }
+}
+
+void BatchImportConfig::setProfileSources(const QStringList& profileSources)
+{
+  if (m_profileSources != profileSources) {
+    m_profileSources = profileSources;
+    emit profileSourcesChanged(m_profileSources);
+  }
+}
+
+void BatchImportConfig::setProfileNames(const QStringList& profileNames)
+{
+  if (m_profileNames != profileNames) {
+    m_profileNames = profileNames;
+    emit profileNamesChanged(m_profileNames);
+  }
+}
