@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 2 Jan 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2017  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -218,10 +218,12 @@ int BatchImportSourcesModel::columnCount(const QModelIndex& parent) const
 bool BatchImportSourcesModel::insertRows(int row, int count,
                                          const QModelIndex&)
 {
-  beginInsertRows(QModelIndex(), row, row + count - 1);
-  for (int i = 0; i < count; ++i)
-    m_sources.insert(row, BatchImportProfile::Source());
-  endInsertRows();
+  if (count > 0) {
+    beginInsertRows(QModelIndex(), row, row + count - 1);
+    for (int i = 0; i < count; ++i)
+      m_sources.insert(row, BatchImportProfile::Source());
+    endInsertRows();
+  }
   return true;
 }
 
@@ -234,10 +236,12 @@ bool BatchImportSourcesModel::insertRows(int row, int count,
 bool BatchImportSourcesModel::removeRows(int row, int count,
                         const QModelIndex&)
 {
-  beginRemoveRows(QModelIndex(), row, row + count - 1);
-  for (int i = 0; i < count; ++i)
-    m_sources.removeAt(row);
-  endRemoveRows();
+  if (count > 0) {
+    beginRemoveRows(QModelIndex(), row, row + count - 1);
+    for (int i = 0; i < count; ++i)
+      m_sources.removeAt(row);
+    endRemoveRows();
+  }
   return true;
 }
 
@@ -275,14 +279,9 @@ void BatchImportSourcesModel::getBatchImportSource(
 void BatchImportSourcesModel::setBatchImportSources(
     const QList<BatchImportProfile::Source>& sources)
 {
-#if QT_VERSION >= 0x040600
   beginResetModel();
   m_sources = sources;
   endResetModel();
-#else
-  m_sources = sources;
-  reset();
-#endif
 }
 
 /**
