@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2013  Urs Fleisch
+ * Copyright (C) 2003-2017  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -27,8 +27,8 @@
 #include "formatconfig.h"
 #include "config.h"
 #include <QString>
-#include <QStringList>
 #include <QLocale>
+#include <QCoreApplication>
 #include "generalconfig.h"
 #include "frame.h"
 
@@ -337,9 +337,104 @@ void FormatConfig::setLocaleName(const QString& localeName)
     m_localeName = localeName;
     delete m_locale;
     m_locale = new QLocale(m_localeName);
+    emit localeNameChanged(m_localeName);
   }
 }
 
+void FormatConfig::setEnableValidation(bool enableValidation)
+{
+  if (m_enableValidation != enableValidation) {
+    m_enableValidation = enableValidation;
+    emit enableValidationChanged(m_enableValidation);
+  }
+}
+
+void FormatConfig::setStrRepMap(const QMap<QString, QString>& strRepMap)
+{
+  if (m_strRepMap != strRepMap) {
+    m_strRepMap = strRepMap;
+    emit strRepMapChanged(m_strRepMap);
+  }
+}
+
+QVariantMap FormatConfig::strRepVariantMap() const
+{
+  QVariantMap map;
+  for (QMap<QString, QString>::const_iterator it = m_strRepMap.constBegin();
+       it != m_strRepMap.constEnd();
+       ++it) {
+    map.insert(it.key(), it.value());
+  }
+  return map;
+}
+
+void FormatConfig::setStrRepVariantMap(const QVariantMap& map)
+{
+  QMap<QString, QString> strRepMap;
+  for (QVariantMap::const_iterator it = map.constBegin();
+       it != map.constEnd();
+       ++it) {
+    strRepMap.insert(it.key(), it.value().toString());
+  }
+  setStrRepMap(strRepMap);
+}
+
+void FormatConfig::setCaseConversion(CaseConversion caseConversion)
+{
+  if (m_caseConversion != caseConversion) {
+    m_caseConversion = caseConversion;
+    emit caseConversionChanged(m_caseConversion);
+  }
+}
+
+void FormatConfig::setStrRepEnabled(bool strRepEnabled)
+{
+  if (m_strRepEnabled != strRepEnabled) {
+    m_strRepEnabled = strRepEnabled;
+    emit strRepEnabledChanged(m_strRepEnabled);
+  }
+}
+
+void FormatConfig::setFormatWhileEditing(bool formatWhileEditing)
+{
+  if (m_formatWhileEditing != formatWhileEditing) {
+    m_formatWhileEditing = formatWhileEditing;
+    emit formatWhileEditingChanged(m_formatWhileEditing);
+  }
+}
+
+/**
+ * String list of case conversion names.
+ */
+QStringList FormatConfig::getCaseConversionNames()
+{
+  static const char* const names[NumCaseConversions] = {
+    QT_TRANSLATE_NOOP("@default", "No changes"),
+    QT_TRANSLATE_NOOP("@default", "All lowercase"),
+    QT_TRANSLATE_NOOP("@default", "All uppercase"),
+    QT_TRANSLATE_NOOP("@default", "First letter uppercase"),
+    QT_TRANSLATE_NOOP("@default", "All first letters uppercase")
+  };
+  QStringList strs;
+  strs.reserve(NumCaseConversions);
+  for (int i = 0; i < NumCaseConversions; ++i) {
+    strs.append(QCoreApplication::translate("@default", names[i]));
+  }
+  return strs;
+}
+
+/**
+ * String list of locale names.
+ */
+QStringList FormatConfig::getLocaleNames()
+{
+  return QStringList() << tr("None")
+#if QT_VERSION >= 0x040800
+                       << QLocale().uiLanguages()
+#endif
+                          ;
+}
+
 
 int FilenameFormatConfig::s_index = -1;
 
