@@ -46,7 +46,7 @@ inline int tagVersionToImportDestCfg(Frame::TagVersion tagVersion) {
  * @return tag version.
  */
 inline Frame::TagVersion importDestCfgToTagVersion(int importDest) {
-  return TrackData::tagVersionCast(importDest + 1);
+  return Frame::tagVersionCast(importDest + 1);
 }
 
 }
@@ -209,22 +209,14 @@ ImportConfig::ImportConfig() :
   m_pictureSourceUrls.append(QLatin1String("http://www.cduniverse.com/sresult.asp?HT_Search_Info=%u{artist}+%u{album}"));
   m_pictureSourceNames.append(QLatin1String("Coveralia"));
   m_pictureSourceUrls.append(QLatin1String("http://www.coveralia.com/mostrar.php?bus=%u{artist}%20%u{album}&bust=2"));
-  m_pictureSourceNames.append(QLatin1String("FreeCovers"));
-  m_pictureSourceUrls.append(QLatin1String("http://www.freecovers.net/search.php?search=%u{artist}+%u{album}&cat=4"));
-  m_pictureSourceNames.append(QLatin1String("CoverHunt"));
-  m_pictureSourceUrls.append(QLatin1String("http://www.coverhunt.com/search/%u{artist}+%u{album}"));
   m_pictureSourceNames.append(QLatin1String("SlothRadio"));
   m_pictureSourceUrls.append(QLatin1String("http://www.slothradio.com/covers/?artist=%u{artist}&album=%u{album}"));
   m_pictureSourceNames.append(QLatin1String("Albumart"));
   m_pictureSourceUrls.append(QLatin1String("http://www.albumart.org/index.php?srchkey=%u{artist}+%u{album}&searchindex=Music"));
-  m_pictureSourceNames.append(QLatin1String("Yalp!"));
-  m_pictureSourceUrls.append(QLatin1String("http://search.yalp.alice.it/search/search.html?txtToSearch=%u{artist}%20%u{album}"));
-  m_pictureSourceNames.append(QLatin1String("HMV"));
-  m_pictureSourceUrls.append(QLatin1String("http://hmv.com/hmvweb/advancedSearch.do?searchType=2&artist=%u{artist}&title=%u{album}"));
   m_pictureSourceNames.append(QLatin1String("Custom Source"));
   m_pictureSourceUrls.append(QLatin1String(""));
 
-  m_matchPictureUrlMap[QLatin1String("http://www.google.(?:[^/]+)/.*imgurl=([^&]+)&.*")] =
+  m_matchPictureUrlMap[QLatin1String("https?://www.google.(?:[^/]+)/.*imgurl=([^&]+)&.*")] =
     QLatin1String("\\1");
   m_matchPictureUrlMap[QLatin1String("http://images.search.yahoo.com/.*&imgurl=([^&]+)&.*")] =
     QLatin1String("http%3A%2F%2F\\1");
@@ -232,8 +224,6 @@ ImportConfig::ImportConfig() :
     QLatin1String("http://images.amazon.com/images/P/\\1.01._SCLZZZZZZZ_.jpg");
   m_matchPictureUrlMap[QLatin1String("http://musicbrainz.org/misc/redirects/.*&asin=([A-Z0-9]+).*")] =
     QLatin1String("http://images.amazon.com/images/P/\\1.01._SCLZZZZZZZ_.jpg");
-  m_matchPictureUrlMap[QLatin1String("http://www.freecovers.net/view/(\\d+)/([0-9a-f]+)/.*")] =
-    QLatin1String("http://www.freecovers.net/preview/\\1/\\2/big.jpg");
   m_matchPictureUrlMap[QLatin1String("(http://.*4shared.com/img/.*)")] =
     QLatin1String("\\1.jpg");
 }
@@ -417,12 +407,17 @@ void ImportConfig::readFromConfig(ISettings* config)
         QLatin1String("http://www.google.com/search?tbm=isch&q=%u{artist}%20%u{album}"));
   if (m_matchPictureUrlMap.remove(QLatin1String(
       "http://images.google.com/.*imgurl=([^&]+)&.*")) != 0) {
-    m_matchPictureUrlMap[QLatin1String("http://www.google.(?:[^/]+)/.*imgurl=([^&]+)&.*")] =
+    m_matchPictureUrlMap[QLatin1String("https?://www.google.(?:[^/]+)/.*imgurl=([^&]+)&.*")] =
       QLatin1String("\\1");
   }
   if (m_matchPictureUrlMap.remove(QLatin1String(
       "http://www.google.com/.*imgurl=([^&]+)&.*")) != 0) {
-    m_matchPictureUrlMap[QLatin1String("http://www.google.(?:[^/]+)/.*imgurl=([^&]+)&.*")] =
+    m_matchPictureUrlMap[QLatin1String("https?://www.google.(?:[^/]+)/.*imgurl=([^&]+)&.*")] =
+      QLatin1String("\\1");
+  }
+  if (m_matchPictureUrlMap.remove(QLatin1String(
+      "http://www.google.(?:[^/]+)/.*imgurl=([^&]+)&.*")) != 0) {
+    m_matchPictureUrlMap[QLatin1String("https?://www.google.(?:[^/]+)/.*imgurl=([^&]+)&.*")] =
       QLatin1String("\\1");
   }
   if (m_matchPictureUrlMap.remove(QLatin1String(
