@@ -28,7 +28,11 @@
 #define IMPORTPARSER_H
 
 #include <QString>
+#if QT_VERSION >= 0x050100
+#include <QRegularExpression>
+#else
 #include <QRegExp>
+#endif
 #include <QMap>
 #include <QList>
 #include "kid3api.h"
@@ -82,13 +86,17 @@ private:
   /** track regexp pattern */
   QString m_pattern;
   /** regexp object */
+#if QT_VERSION >= 0x050100
+  QRegularExpression m_re;
+#else
   QRegExp m_re;
-  /** true if automatic track number incrementing is used */
-  bool m_trackIncrEnabled;
+#endif
   /** automatically incremented track number */
   int m_trackIncrNr;
   QMap<QString, int> m_codePos;
   QList<int> m_trackDuration;
+  /** true if automatic track number incrementing is used */
+  bool m_trackIncrEnabled;
 };
 
 #endif
