@@ -91,6 +91,13 @@ public:
    */
   virtual void setSourceModel(QAbstractItemModel* sourceModel);
 
+  /**
+   * Check if more data is available.
+   * @param parent parent index of items to fetch
+   * @return true if more data available.
+   */
+  virtual bool canFetchMore(const QModelIndex& parent) const;
+
   /**
    * Fetches any available data.
    * @param parent parent index of items to fetch
@@ -117,6 +124,11 @@ public:
   virtual QHash<int, QByteArray> roleNames() const;
 #endif
 
+  /**
+   * Reset the model.
+   */
+  void resetModel();
+
   /**
    * Check if the model is currently loading a directory.
    * @return true if loading is in progress.
@@ -151,6 +163,14 @@ public:
    */
   void applyFilteringOutIndexes();
 
+  /**
+   * Set filters for included and excluded folders.
+   * @param includeFolders wildcard expressions for folders to be included
+   * @param excludeFolders wildcard expressions for folders to be excluded
+   */
+  void setFolderFilters(const QStringList& includeFolders,
+                        const QStringList& excludeFolders);
+
   /**
    * Get file information of model index.
    * @return file information
@@ -376,6 +396,13 @@ signals:
    */
   void modifiedChanged(bool modified);
 
+protected slots:
+  /**
+   * Reset internal data of the model.
+   * Is called from endResetModel().
+   */
+  void resetInternalData();
+
 private slots:
   /**
    * Update the TaggedFile contents for rows inserted into the model.
@@ -439,8 +466,24 @@ private:
    */
   void initTaggedFileData(const QModelIndex& index);
 
+  /**
+   * Check if a directory path passes the include folder filters.
+   * @param dirPath absolute path to directory
+   * @return true if path passes filters.
+   */
+  bool passesIncludeFolderFilters(const QString& dirPath) const;
+
+  /**
+   * Check if a directory path passes the exclude folder filters.
+   * @param dirPath absolute path to directory
+   * @return true if path passes filters.
+   */
+  bool passesExcludeFolderFilters(const QString& dirPath) const;
+
   QHash<QPersistentModelIndex, TaggedFile*> m_taggedFiles;
   QSet<QPersistentModelIndex> m_filteredOut;
+  QList<QRegExp> m_includeFolderFilters;
+  QList<QRegExp> m_excludeFolderFilters;
   TaggedFileIconProvider* m_iconProvider;
   QFileSystemModel* m_fsModel;
   QTimer* m_loadTimer;
