@@ -35,6 +35,7 @@
 #include "genremodel.h"
 #include "tracknumbervalidator.h"
 #include "pictureframe.h"
+#include "framenotice.h"
 
 namespace {
 
@@ -94,7 +95,8 @@ QHash<int,QByteArray> getRoleHash()
  */
 FrameTableModel::FrameTableModel(bool id3v1, QObject* parent) :
   QAbstractTableModel(parent), m_markedRows(0), m_changedFrames(0),
-  m_id3v1(id3v1)
+  m_id3v1(id3v1),
+  m_guiApp(qobject_cast<QApplication*>(QCoreApplication::instance()) != 0)
 {
   setObjectName(QLatin1String("FrameTableModel"));
 #if QT_VERSION < 0x050000
@@ -148,7 +150,8 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
       (static_cast<unsigned>((*it).getType()) < sizeof(m_changedFrames) * 8 &&
        (m_changedFrames & (1ULL << (*it).getType())) != 0));
   }
-  if ((role == Qt::BackgroundColorRole && index.column() == CI_Value) ||
+  if (((role == Qt::BackgroundColorRole || role == Qt::ToolTipRole) &&
+       index.column() == CI_Value) ||
       role == TruncatedRole) {
     isTruncated = (static_cast<unsigned>(index.row()) < sizeof(m_markedRows) * 8 &&
         (m_markedRows & (1ULL << index.row())) != 0) || it->isMarked();
@@ -178,10 +181,20 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
     return m_frameSelected.at(index.row()) ? Qt::Checked : Qt::Unchecked;
   } else if (role == Qt::BackgroundColorRole) {
     if (index.column() == CI_Enable) {
-      return isModified ? QApplication::palette().mid() : Qt::NoBrush;
+      return !isModified ? Qt::NoBrush
+                         : m_guiApp ? QApplication::palette().mid()
+                                    : QBrush(Qt::gray);
     } else if (index.column() == CI_Value) {
       return isTruncated ? QBrush(Qt::red) : Qt::NoBrush;
     }
+  } else if (role == Qt::ToolTipRole) {
+    QString toolTip;
+    if (isTruncated && index.column() == CI_Value) {
+      FrameNotice notice = it->isMarked() ? it->getNotice()
+                                          : FrameNotice::Truncated;
+      toolTip = notice.getDescription();
+    }
+    return toolTip;
   } else if (role == FrameTypeRole) {
     return it->getType();
   } else if (role == NameRole) {
@@ -729,15 +742,8 @@ FrameItemDelegate::FrameItemDelegate(GenreModel* genreModel, QObject* parent) :
   QItemDelegate(parent),
   m_genreModel(genreModel),
   m_trackNumberValidator(new TrackNumberValidator(this)),
-  m_dateTimeValidator(new QRegExpValidator(QRegExp(QLatin1String(
-    // This is a simplified regular expression from
-    // http://www.pelagodesign.com/blog/2009/05/20/iso-8601-date-validation-that-doesnt-suck/
-    // relaxed to allow appending any string after a slash, so that ISO 8601
-    // periods of time can by entered while still providing suffient validation.
-    "(\\d{4})(-((0[1-9]|1[0-2])(-([12]\\d|0[1-9]|3[01]))?)(T((([01]\\d|2[0-3])"
-    "(:[0-5]\\d)?|24:00))?(:[0-5]\\d([\\.,]\\d+)?)?"
-    "([zZ]|([\\+-])([01]\\d|2[0-3]):?([0-5]\\d)?)?)?(/.*)?)?"
-  )), this)) {
+  m_dateTimeValidator(new QRegExpValidator(FrameNotice::isoDateTimeRexExp(),
+                                           this)) {
   setObjectName(QLatin1String("FrameItemDelegate"));
 }
 
