@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Jul 2011
  *
- * Copyright (C) 2011-2012  Urs Fleisch
+ * Copyright (C) 2011-2017  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -40,6 +40,7 @@
 class QFileIconProvider;
 class QFileSystemModel;
 class QItemSelectionModel;
+class QItemSelection;
 class QModelIndex;
 class QNetworkAccessManager;
 class QDir;
@@ -98,6 +99,10 @@ class KID3_CORE_EXPORT Kid3Application : public QObject {
   Q_PROPERTY(bool modified READ isModified NOTIFY modifiedChanged)
   /** Filtered state. */
   Q_PROPERTY(bool filtered READ isFiltered WRITE setFiltered NOTIFY filteredChanged)
+  /** Number of files which have passed the filter. */
+  Q_PROPERTY(int filterPassedCount READ filterPassedCount NOTIFY fileFiltered)
+  /** Total number of files checked by filter. */
+  Q_PROPERTY(int filterTotalCount READ filterTotalCount NOTIFY fileFiltered)
   /** Frame editor. */
   Q_PROPERTY(FrameEditorObject* frameEditor READ frameEditor WRITE setFrameEditor
              NOTIFY frameEditorChanged)
@@ -139,6 +144,14 @@ public:
    */
   virtual ~Kid3Application();
 
+#ifdef HAVE_QTDBUS
+  /**
+   * Activate the D-Bus interface.
+   * This method shall be called only once at initialization.
+   */
+  void activateDbusInterface();
+#endif
+
  /**
   * Get file system model.
   * @return file system model.
@@ -361,7 +374,9 @@ public:
    * Get root index of opened directory in directory proxy model.
    * @return index of directory root.
    */
-  QModelIndex getDirRootIndex() const { return m_dirProxyModelRootIndex; }
+  QPersistentModelIndex getDirRootIndex() const {
+    return m_dirProxyModelRootIndex;
+  }
 
   /**
    * Get directory path of opened directory.
@@ -371,7 +386,7 @@ public:
 
   /**
    * Save all changed files.
-   * saveStarted() and saveProgress() are emitted while saving files.
+   * longRunningOperationProgress() is emitted while saving files.
    *
    * @return list of files with error, empty if ok.
    */
@@ -388,6 +403,13 @@ public:
    */
   Q_INVOKABLE void tagsToFrameModels();
 
+  /**
+   * Update frame models to contain contents of item selection.
+   * The properties starting with "selection" will be set by this method.
+   * @param selected item selection
+   */
+  void selectedTagsToFrameModels(const QItemSelection& selected);
+
   /**
    * Access to information about selected tagged files.
    * @return selection information.
@@ -656,6 +678,24 @@ public:
    */
   bool isFiltered() const { return m_filtered; }
 
+  /**
+   * Get number of files which have passed the filter.
+   *
+   * This number is only valid if isFiltered() is true.
+   *
+   * @return number of files which have passed the filter.
+   */
+  int filterPassedCount() const { return m_filterPassed; }
+
+  /**
+   * Get total number of files which have been checked by the filter.
+   *
+   * This number is only valid if isFiltered() is true.
+   *
+   * @return total number of files checked by filter.
+   */
+  int filterTotalCount() const { return m_filterTotal; }
+
   /**
    * Get the selected file.
    *
@@ -727,6 +767,14 @@ public:
    */
   Q_INVOKABLE void setFileSelectionIndexes(const QVariantList& indexes);
 
+  /**
+   * Get paths to all selected files.
+   * @param onlyTaggedFiles only consider tagged files
+   * @return list of absolute file paths.
+   */
+  Q_INVOKABLE QStringList getSelectedFilePaths(bool onlyTaggedFiles = true)
+  const;
+
   /**
    * Set picture data for image provider.
    * @param picture picture data
@@ -882,9 +930,10 @@ public slots:
    * Delete selected frame.
    * @param tagNr tag number
    * @param frameName name of frame to delete, empty to delete selected frame
+   * @param index 0 for first frame with @a frameName, 1 for second, etc.
    */
   void deleteFrame(Frame::TagNumber tagNr,
-                   const QString& frameName = QString());
+                   const QString& frameName = QString(), int index = 0);
 
   /**
    * Select a frame type and add such a frame to the frame list.
@@ -911,28 +960,31 @@ public slots:
    * Set the first file as the current file.
    *
    * @param select true to select the file
+   * @param onlyTaggedFiles only consider tagged files
    *
    * @return true if a file exists.
    */
-  bool firstFile(bool select = true);
+  bool firstFile(bool select = true, bool onlyTaggedFiles = false);
 
   /**
    * Set the next file as the current file.
    *
    * @param select true to select the file
+   * @param onlyTaggedFiles only consider tagged files
    *
    * @return true if a next file exists.
    */
-  bool nextFile(bool select = true);
+  bool nextFile(bool select = true, bool onlyTaggedFiles = false);
 
   /**
    * Set the previous file as the current file.
    *
    * @param select true to select the file
+   * @param onlyTaggedFiles only consider tagged files
    *
    * @return true if a previous file exists.
    */
-  bool previousFile(bool select = true);
+  bool previousFile(bool select = true, bool onlyTaggedFiles = false);
 
   /**
    * Select or deselect the current file.
@@ -958,6 +1010,16 @@ public slots:
    */
   void selectAllInDirectory();
 
+  /**
+   * Set a specific file as the current file.
+   *
+   * @param filePath path to file
+   * @param select true to select the file
+   *
+   * @return true if file exists.
+   */
+  bool selectFile(const QString& filePath, bool select = true);
+
   /**
    * Fetch entries of directory if not already fetched.
    * This works like FileList::expand(), but without expanding tree view
@@ -988,8 +1050,11 @@ public slots:
   /**
    * Process change of selection.
    * The GUI is signaled to update the current selection and the controls.
+   * @param selected selected items
+   * @param deselected deselected items
    */
-  void fileSelected();
+  void fileSelected(const QItemSelection& selected,
+                    const QItemSelection& deselected);
 
   /**
    * Search in tags for a given text.
@@ -1060,6 +1125,18 @@ public slots:
    * Show play tool bar.
    */
   void showAudioPlayer();
+
+#ifdef HAVE_QTDBUS
+  /**
+   * Activate the MPRIS D-Bus Interface if not already active.
+   */
+  void activateMprisInterface();
+
+  /**
+   * Deactivate the MPRIS D-Bus Interface if it is active.
+   */
+  void deactivateMprisInterface();
+#endif
 #endif
 
   /**
@@ -1093,18 +1170,6 @@ signals:
    */
   void confirmedOpenDirectoryRequested(const QStringList& paths);
 
-  /**
-   * Emitted when saving files is started.
-   * @param totalFiles total number of files to be saved
-   */
-  void saveStarted(int totalFiles);
-
-  /**
-   * Emitted when a file has bee saved.
-   * @param numFiles number of files saved
-   */
-  void saveProgress(int numFiles);
-
   /**
    * Emitted before an operation on the selected files is performed.
    * The GUI should update the files of the current selection when
@@ -1119,6 +1184,16 @@ signals:
    */
   void selectedFilesUpdated();
 
+  /**
+   * Emitted after the file selection is changed.
+   * The GUI should update its controls from the tags of the new file selection
+   * when receiving this signal.
+   * @param selected selected items
+   * @param deselected deselected items
+   */
+  void selectedFilesChanged(const QItemSelection& selected,
+                            const QItemSelection& deselected);
+
   /**
    * Emitted after a frame of a tagged file has been modified.
    * The GUI should update the corresponding controls when receiving this
@@ -1153,8 +1228,10 @@ signals:
    * Emitted when a file is filtered.
    * @param type filter event type, enum FileFilter::FilterEventType
    * @param fileName name of filtered file
+   * @param passed number of files which passed the filter
+   * @param total total number of files checked
    */
-  void fileFiltered(int type, const QString& fileName);
+  void fileFiltered(int type, const QString& fileName, int passed, int total);
 
   /**
    * Emitted before an audio file is played.
@@ -1203,7 +1280,28 @@ signals:
    */
   void frameEditorChanged();
 
+  /**
+   * Emitted to report progress about a long running operation.
+   *
+   * This signal is used to report different states of a long running operation.
+   * - Operation is started: done is -1,
+   * - Operation is finished: done == total and total is not 0,
+   * - Operation in progress: done < total or both done and total are 0
+   *
+   * @param name name of operation
+   * @param done amount of work done
+   * @param total total amount of work
+   * @param abort if not 0, can be set to true to abort the operation
+   */
+  void longRunningOperationProgress(const QString& name, int done, int total,
+                                    bool* abort);
+
 private slots:
+  /**
+   * Apply file filter after the file system model has been reset.
+   */
+  void applyFilterAfterReset();
+
   /**
    * Apply single file to file filter.
    *
@@ -1267,6 +1365,16 @@ private:
    */
   void checkPlugin(QObject* plugin);
 
+  /**
+   * Update frame models to contain contents of selected files.
+   * @param indexes tagged file indexes
+   * @param startSelection true if a new selection is started, false to add to
+   * the existing selection
+   * @return true if ok, false if selection operation is already running.
+   */
+  bool addTaggedFilesToSelection(
+      const QList<QPersistentModelIndex>& indexes, bool startSelection);
+
   /**
    * Select a frame type and add such a frame to frame list.
    * @param tagNr tag number
@@ -1276,6 +1384,25 @@ private:
    */
   void addFrame(Frame::TagNumber tagNr, const Frame* frame, bool edit = false);
 
+  /**
+   * Open directory after resetting the file system model.
+   * This will create a new file system model and reset the file and directory
+   * proxy models.
+   * When finished directoryOpened() is emitted, also if false is returned.
+   *
+   * @param paths file or directory paths, if multiple paths are given, the
+   * common directory is opened and the files are selected, if empty, the
+   * currently open directory is reopened
+   *
+   * @return true if ok.
+   */
+  bool openDirectoryAfterReset(const QStringList& paths = QStringList());
+
+  /**
+   * Second stage for applyFilter().
+   */
+  void proceedApplyingFilter();
+
   /**
    * Set the coverArtImageId property to a new value.
    * This can be used to trigger an update of QML images.
@@ -1288,10 +1415,8 @@ private:
   /** Configuration */
   ConfigStore* m_configStore;
   /** model of filesystem */
-#ifdef Q_OS_MAC
   QFileIconProvider* m_defaultFileIconProvider;
   QFileIconProvider* m_fileIconProvider;
-#endif
   QFileSystemModel* m_fileSystemModel;
   FileProxyModel* m_fileProxyModel;
   FileProxyModelIterator* m_fileProxyModelIterator;
@@ -1322,6 +1447,9 @@ private:
 #if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /** Audio player */
   AudioPlayer* m_player;
+#ifdef HAVE_QTDBUS
+  QString m_mprisServiceName;
+#endif
 #endif
   FileFilter* m_expressionFileFilter;
   /** Information about selected tagged files */
@@ -1333,7 +1461,7 @@ private:
   /** Root index in file proxy model */
   QPersistentModelIndex m_fileProxyModelRootIndex;
   /** Root index in directory proxy model */
-  QModelIndex m_dirProxyModelRootIndex;
+  QPersistentModelIndex m_dirProxyModelRootIndex;
   /** Indexes of opened file in file proxy model */
   QList<QPersistentModelIndex> m_fileProxyModelFileIndexes;
   /** Importers for different servers */
@@ -1352,6 +1480,8 @@ private:
   /* Context for filterNextFile() */
   FileFilter* m_fileFilter;
   QString m_lastProcessedDirName;
+  int m_filterPassed;
+  int m_filterTotal;
   /* Context for batchImportNextFile() */
   BatchImportProfile* m_namedBatchImportProfile;
   const BatchImportProfile* m_batchImportProfile;
@@ -1373,8 +1503,14 @@ private:
   PixmapProvider* m_imageProvider;
   QString m_coverArtImageId;
 
+#ifdef HAVE_QTDBUS
+  /** true if D-Bus is enabled */
+  bool m_dbusEnabled;
+#endif
   /** true if list is filtered */
   bool m_filtered;
+  /** true if a selection operation is running */
+  bool m_selectionOperationRunning;
 
   /** Fallback for path to search for plugins */
   static QString s_pluginsPathFallback;
