@@ -98,6 +98,17 @@ public slots:
    */
   bool importFromFile(int tagMask, const QString& path, int fmtIdx);
 
+  /**
+   * Import from tags.
+   *
+   * @param tagMask tag mask
+   * @param source format to get source text from tags
+   * @param extraction regular expression with frame names and captures to
+   * extract from source text
+   */
+  void importFromTags(int tagMask,
+                      const QString& source, const QString& extraction);
+
   /**
    * Start an automatic batch import.
    *
