@@ -255,18 +255,14 @@ bool TagSearcher::searchInFile(TaggedFile* taggedFile, Position* pos,
       return true;
     }
   }
-  if (pos->getPart() <= Position::Tag1) {
-    FrameCollection frames;
-    taggedFile->getAllFramesV1(frames);
-    if (searchInFrames(frames, Position::Tag1, pos, advanceChars)) {
-      return true;
-    }
-  }
-  if (pos->getPart() <= Position::Tag2) {
-    FrameCollection frames;
-    taggedFile->getAllFramesV2(frames);
-    if (searchInFrames(frames, Position::Tag2, pos, advanceChars)) {
-      return true;
+  FOR_ALL_TAGS(tagNr) {
+    Position::Part part = Position::tagNumberToPart(tagNr);
+    if (pos->getPart() <= part) {
+      FrameCollection frames;
+      taggedFile->getAllFrames(tagNr, frames);
+      if (searchInFrames(frames, part, pos, advanceChars)) {
+        return true;
+      }
     }
   }
   return false;
@@ -338,9 +334,7 @@ void TagSearcher::replaceNext()
   if (m_currentPosition.isValid()) {
     if (TaggedFile* taggedFile =
         FileProxyModel::getTaggedFileOfIndex(m_currentPosition.getFileIndex())) {
-      switch (m_currentPosition.getPart()) {
-      case Position::FileName:
-      {
+      if (m_currentPosition.getPart() == Position::FileName) {
         QString str = taggedFile->getFilename();
         replaced = str.mid(m_currentPosition.getMatchedPos(),
                            m_currentPosition.getMatchedLength());
@@ -348,17 +342,10 @@ void TagSearcher::replaceNext()
         str.replace(m_currentPosition.getMatchedPos(),
                     m_currentPosition.getMatchedLength(), replaced);
         taggedFile->setFilename(str);
-        break;
-      }
-      case Position::Tag1:
-      case Position::Tag2:
-      {
+      } else {
         FrameCollection frames;
-        if (m_currentPosition.getPart() == Position::Tag1) {
-          taggedFile->getAllFramesV1(frames);
-        } else {
-          taggedFile->getAllFramesV2(frames);
-        }
+        taggedFile->getAllFrames(
+              Position::partToTagNumber(m_currentPosition.getPart()), frames);
         FrameCollection::iterator it = frames.begin();
         FrameCollection::iterator end = frames.end();
         for (int frameNr = 0;
@@ -375,14 +362,9 @@ void TagSearcher::replaceNext()
           str.replace(m_currentPosition.getMatchedPos(),
                       m_currentPosition.getMatchedLength(), replaced);
           frame.setValueIfChanged(str);
-          if (m_currentPosition.getPart() == Position::Tag1) {
-            taggedFile->setFramesV1(frames);
-          } else {
-            taggedFile->setFramesV2(frames);
-          }
+          taggedFile->setFrames(
+                Position::partToTagNumber(m_currentPosition.getPart()), frames);
         }
-        break;
-      }
       }
     }
   }
@@ -427,14 +409,20 @@ void TagSearcher::replaceThenFindNext()
  */
 int TagSearcher::findInString(const QString& str, int& idx) const
 {
-  if (m_regExp.isEmpty()) {
+  if (m_regExp.pattern().isEmpty()) {
     idx = str.indexOf(m_params.getSearchText(), idx,
                       m_params.getFlags() & CaseSensitive
                       ? Qt::CaseSensitive : Qt::CaseInsensitive);
     return idx != -1 ? m_params.getSearchText().length() : -1;
   } else {
+#if QT_VERSION >= 0x050100
+    QRegularExpressionMatch match = m_regExp.match(str, idx);
+    idx = match.capturedStart();
+    return match.hasMatch() ? match.capturedLength() : -1;
+#else
     idx = m_regExp.indexIn(str, idx);
     return idx != -1 ? m_regExp.matchedLength() : -1;
+#endif
   }
 }
 
@@ -444,7 +432,7 @@ int TagSearcher::findInString(const QString& str, int& idx) const
  */
 void TagSearcher::replaceString(QString& str) const
 {
-  if (m_regExp.isEmpty()) {
+  if (m_regExp.pattern().isEmpty()) {
     str.replace(m_params.getSearchText(), m_params.getReplaceText(),
                 m_params.getFlags() & CaseSensitive
                 ? Qt::CaseSensitive : Qt::CaseInsensitive);
@@ -464,12 +452,24 @@ void TagSearcher::setParameters(Parameters params)
   if (m_iterator) {
     m_iterator->setDirectionBackwards(flags & Backwards);
   }
+#if QT_VERSION >= 0x050100
+  if (flags & RegExp) {
+    m_regExp.setPattern(m_params.getSearchText());
+    m_regExp.setPatternOptions(flags & CaseSensitive
+                               ? QRegularExpression::NoPatternOption
+                               : QRegularExpression::CaseInsensitiveOption);
+  } else {
+    m_regExp.setPattern(QString());
+    m_regExp.setPatternOptions(QRegularExpression::NoPatternOption);
+  }
+#else
   if (flags & RegExp) {
     m_regExp = QRegExp(m_params.getSearchText(), flags & CaseSensitive
                        ? Qt::CaseSensitive : Qt::CaseInsensitive);
   } else {
     m_regExp = QRegExp();
   }
+#endif
 }
 
 /**
@@ -481,17 +481,13 @@ QString TagSearcher::getLocationString(TaggedFile* taggedFile) const
 {
   QString location = taggedFile->getFilename();
   location += QLatin1String(": ");
-  switch (m_currentPosition.getPart()) {
-  case Position::FileName:
+  if (m_currentPosition.getPart() == Position::FileName) {
     location += tr("Filename");
-    break;
-  case Position::Tag1:
-  case Position::Tag2:
-    location += m_currentPosition.getPart() == Position::Tag1
-        ? tr("Tag 1") : tr("Tag 2");
+  } else {
+    location += tr("Tag %1").arg(Frame::tagNumberToString(
+          Position::partToTagNumber(m_currentPosition.getPart())));
     location += QLatin1String(": ");
     location += m_currentPosition.getFrameName();
-    break;
   }
   return location;
 }
