@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 14 Mar 2014
  *
- * Copyright (C) 2014  Urs Fleisch
+ * Copyright (C) 2014-2017  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -34,7 +34,8 @@
  * @param parent parent widget
  */
 TimeEventModel::TimeEventModel(QObject* parent) :
-  QAbstractTableModel(parent), m_type(SynchronizedLyrics), m_markedRow(-1)
+  QAbstractTableModel(parent), m_type(SynchronizedLyrics), m_markedRow(-1),
+  m_guiApp(qobject_cast<QApplication*>(QCoreApplication::instance()) != 0)
 {
   setObjectName(QLatin1String("TimeEventModel"));
 }
@@ -78,8 +79,9 @@ QVariant TimeEventModel::data(const QModelIndex& index, int role) const
     else
       return timeEvent.data;
   } else if (role == Qt::BackgroundColorRole && index.column() == CI_Data) {
-    return index.row() == m_markedRow
-        ? QApplication::palette().mid() : Qt::NoBrush;
+    return index.row() != m_markedRow ? Qt::NoBrush
+                                      : m_guiApp ? QApplication::palette().mid()
+                                                 : QBrush(Qt::gray);
   }
   return QVariant();
 }
@@ -199,15 +201,9 @@ bool TimeEventModel::removeRows(int row, int count,
  */
 void TimeEventModel::setTimeEvents(const QList<TimeEvent>& events)
 {
-#if QT_VERSION >= 0x040600
   beginResetModel();
-#endif
   m_timeEvents = events;
-#if QT_VERSION >= 0x040600
   endResetModel();
-#else
-  reset();
-#endif
 }
 
 /**
@@ -231,7 +227,7 @@ void TimeEventModel::fromSyltFrame(const Frame::FieldList& fields)
        it != fields.constEnd();
        ++it) {
     const Frame::Field& fld = *it;
-    if (fld.m_id == Frame::Field::ID_TimestampFormat) {
+    if (fld.m_id == Frame::ID_TimestampFormat) {
       unitIsFrames = fld.m_value.toInt() == 1;
     } else if (fld.m_value.type() == QVariant::List) {
       synchedData = fld.m_value.toList();
@@ -296,7 +292,7 @@ void TimeEventModel::toSyltFrame(Frame::FieldList& fields) const
   for (Frame::FieldList::iterator it = fields.begin();
        it != fields.end();
        ++it) {
-    if (it->m_id == Frame::Field::ID_TimestampFormat) {
+    if (it->m_id == Frame::ID_TimestampFormat) {
       timeStampFormatIt = it;
     } else if (it->m_value.type() == QVariant::List) {
       dataIt = it;
@@ -350,7 +346,7 @@ void TimeEventModel::fromEtcoFrame(const Frame::FieldList& fields)
        it != fields.constEnd();
        ++it) {
     const Frame::Field& fld = *it;
-    if (fld.m_id == Frame::Field::ID_TimestampFormat) {
+    if (fld.m_id == Frame::ID_TimestampFormat) {
       unitIsFrames = fld.m_value.toInt() == 1;
     } else if (fld.m_value.type() == QVariant::List) {
       synchedData = fld.m_value.toList();
@@ -384,7 +380,7 @@ void TimeEventModel::toEtcoFrame(Frame::FieldList& fields) const
   for (Frame::FieldList::iterator it = fields.begin();
        it != fields.end();
        ++it) {
-    if (it->m_id == Frame::Field::ID_TimestampFormat) {
+    if (it->m_id == Frame::ID_TimestampFormat) {
       timeStampFormatIt = it;
     } else if (it->m_value.type() == QVariant::List) {
       dataIt = it;
@@ -658,12 +654,20 @@ void TimeEventModel::toLrcFile(QTextStream& stream, const QString& title,
  */
 QString TimeEventModel::timeStampToString(const QTime& time)
 {
+  int hour = time.hour();
+  int min = time.minute();
+  int sec = time.second();
+  int msec = time.msec();
+  if (hour < 0) hour = 0;
+  if (min < 0)  min = 0;
+  if (sec < 0)  sec = 0;
+  if (msec < 0) msec = 0;
   QString text = QString(QLatin1String("%1:%2.%3")).
-      arg(time.minute(), 2, 10, QLatin1Char('0')).
-      arg(time.second(), 2, 10, QLatin1Char('0')).
-      arg(time.msec() / 10, 2, 10, QLatin1Char('0'));
-  if (time.hour() != 0) {
-    text.prepend(QString::number(time.hour()) + QLatin1Char(':'));
+      arg(min, 2, 10, QLatin1Char('0')).
+      arg(sec, 2, 10, QLatin1Char('0')).
+      arg(msec / 10, 2, 10, QLatin1Char('0'));
+  if (hour != 0) {
+    text.prepend(QString::number(hour) + QLatin1Char(':'));
   }
   return text;
 }
