@@ -301,6 +301,8 @@ QMap<QByteArray, QByteArray> getDisplayNamesOfIds()
     { "\251mvi", QT_TRANSLATE_NOOP("@default", "Movement Number") },
     { "\251mvc", QT_TRANSLATE_NOOP("@default", "Movement Count") },
     { "shwm", QT_TRANSLATE_NOOP("@default", "Show Work & Movement") },
+    { "ownr", QT_TRANSLATE_NOOP("@default", "Owner") },
+    { "xid ", QT_TRANSLATE_NOOP("@default", "XID") },
     { "IARL", QT_TRANSLATE_NOOP("@default", "Archival Location") },
     { "ICMS", QT_TRANSLATE_NOOP("@default", "Commissioned") },
     { "ICRP", QT_TRANSLATE_NOOP("@default", "Cropped") },
@@ -358,7 +360,7 @@ QString Frame::ExtendedType::getTranslatedName() const
  * Constructor.
  */
 Frame::Frame() :
-  m_index(-1), m_valueChanged(false), m_marked(false)
+  m_index(-1), m_marked(FrameNotice::None), m_valueChanged(false)
 {
 }
 
@@ -368,7 +370,7 @@ Frame::Frame() :
 Frame::Frame(Type type, const QString& value,
              const QString& name, int index) :
   m_extendedType(type, name), m_index(index), m_value(value),
-  m_valueChanged(false), m_marked(false)
+  m_marked(FrameNotice::None), m_valueChanged(false)
 {
 }
 
@@ -379,8 +381,8 @@ Frame::Frame(Type type, const QString& value,
  * @param index index inside tag, -1 if unknown
  */
 Frame::Frame(const ExtendedType& type, const QString& value, int index) :
-  m_extendedType(type), m_index(index), m_value(value), m_valueChanged(false),
-  m_marked(false)
+  m_extendedType(type), m_index(index), m_value(value),
+  m_marked(FrameNotice::None), m_valueChanged(false)
 {
 }
 
@@ -581,6 +583,22 @@ bool Frame::setField(Frame& frame, FieldId id, const QVariant& value)
   return false;
 }
 
+/**
+ * Set value of a field.
+ *
+ * @param frame frame to set
+ * @param fieldName name of field, can be English or translated
+ * @param value field value
+ *
+ * @return true if field found and set.
+ */
+bool Frame::setField(Frame& frame, const QString& fieldName,
+                     const QVariant& value)
+{
+  const FieldId id = Field::getFieldId(fieldName);
+  return id != ID_NoField && setField(frame, id, value);
+}
+
 /**
  * Get value of a field.
  *
@@ -605,6 +623,20 @@ QVariant Frame::getField(const Frame& frame, FieldId id)
   return result;
 }
 
+/**
+ * Get value of a field.
+ *
+ * @param frame frame to get
+ * @param fieldName name of field, can be English or translated
+ *
+ * @return field value, invalid if not found.
+ */
+QVariant Frame::getField(const Frame& frame, const QString& fieldName)
+{
+  const FieldId id = Field::getFieldId(fieldName);
+  return id != ID_NoField ? getField(frame, id) : QVariant();
+}
+
 /**
  * Get type of frame from English name.
  *
@@ -749,6 +781,37 @@ const char* const* Frame::Field::getFieldIdNames()
   return fieldIdNames;
 }
 
+/**
+ * Get field ID from field name.
+ * @param fieldName name of field, can be English or translated
+ * @return field ID, ID_NoField if not found.
+ */
+Frame::FieldId Frame::Field::getFieldId(const QString& fieldName)
+{
+  const char* const* fn;
+  int id;
+  // First try to find an exact English match.
+  for (fn = fieldIdNames, id = 0; *fn != 0; ++fn, ++id) {
+    if (fieldName == QLatin1String(*fn)) {
+      return static_cast<FieldId>(id);
+    }
+  }
+  // Then try to find a lowercase match ignoring spaces.
+  QString lcName = fieldName.toLower().remove(QLatin1Char(' '));
+  for (fn = fieldIdNames, id = 0; *fn != 0; ++fn, ++id) {
+    if (lcName ==  QString::fromLatin1(*fn).toLower().remove(QLatin1Char(' '))) {
+      return static_cast<FieldId>(id);
+    }
+  }
+  // Finally try to find a translated name.
+  for (fn = fieldIdNames, id = 0; *fn != 0; ++fn, ++id) {
+    if (fieldName == QCoreApplication::translate("@default", *fn)) {
+      return static_cast<FieldId>(id);
+    }
+  }
+  return ID_NoField;
+}
+
 /**
  * Get a translated string for a text encoding.
  *
@@ -891,10 +954,10 @@ static QString variantToString(const QVariant& val)
  */
 void Frame::dump() const
 {
-  qDebug("Frame: name=%s, value=%s, type=%s, index=%d, valueChanged=%u, marked=%u",
+  qDebug("Frame: name=%s, value=%s, type=%s, index=%d, valueChanged=%u, marked=%s",
          getInternalName().toLatin1().data(), m_value.toLatin1().data(),
          getNameFromType(getType()), m_index,
-         m_valueChanged, m_marked);
+         m_valueChanged, qPrintable(m_marked.getDescription()));
   qDebug("  fields=");
   for (FieldList::const_iterator it = m_fieldList.begin();
        it != m_fieldList.end();
@@ -924,26 +987,32 @@ quint64 FrameCollection::s_quickAccessFrames =
 void FrameCollection::filterDifferent(FrameCollection& others)
 {
   QByteArray frameData, othersData;
-  for (iterator it = begin(); it != end(); ++it) {
+  iterator it = begin();
+  while (it != end()) {
     Frame& frame = const_cast<Frame&>(*it);
     // This frame list is not tied to a specific file, so the
     // index is not valid.
     frame.setIndex(-1);
     iterator othersIt = others.find(frame);
-    if (othersIt == others.end() ||
-        (frame.getType() != Frame::FT_Picture &&
-         frame.getValue() != othersIt->getValue()) ||
-        (frame.getType() == Frame::FT_Picture &&
-         !(PictureFrame::getData(frame, frameData) &&
-           PictureFrame::getData(*othersIt, othersData) &&
-           frameData == othersData))) {
+    if (othersIt == others.end()) {
       frame.setDifferent();
-    }
-    while (othersIt != others.end() && !(frame < *othersIt)) {
-      // Mark equal frames as already handled using index -2, used below.
-      // This is probably faster than removing the frames.
-      const_cast<Frame&>(*othersIt).setIndex(-2);
-      ++othersIt;
+      ++it;
+    } else {
+      while (it != end() && othersIt != others.end() &&
+             !(frame < *it) && !(frame < *othersIt)) {
+        if ((it->getType() != Frame::FT_Picture &&
+             it->getValue() != othersIt->getValue()) ||
+            (it->getType() == Frame::FT_Picture &&
+             !(PictureFrame::getData(*it, frameData) &&
+               PictureFrame::getData(*othersIt, othersData) &&
+               frameData == othersData))) {
+          const_cast<Frame&>(*it).setDifferent();
+        }
+        // Mark as already handled.
+        const_cast<Frame&>(*othersIt).setIndex(-2);
+        ++it;
+        ++othersIt;
+      }
     }
   }
 
@@ -1112,28 +1181,36 @@ FrameCollection::const_iterator FrameCollection::searchByName(
  * @param name  the name of the frame to find, if the exact name is not
  *              found, a case-insensitive search for the first name
  *              starting with this string is performed
+ * @param index 0 for first frame with @a name, 1 for second, etc.
  *
  * @return iterator or end() if not found.
  */
-FrameCollection::const_iterator FrameCollection::findByName(const QString& name) const
+FrameCollection::const_iterator FrameCollection::findByName(
+    const QString& name, int index) const
 {
   Frame frame(Frame::ExtendedType(name), QLatin1String(""), -1);
   const_iterator it = find(frame);
-  if (it != end()) {
-    return it;
-  }
-  it = searchByName(name);
-  if (it != end()) {
-    return it;
-  }
-  foreach (const QByteArray& id, getDisplayNamesOfIds().keys(name.toLatin1())) {
-    if (!id.isEmpty()) {
-      it = searchByName(QString::fromLatin1(id));
-      if (it != end()) {
-        break;
+  if (it == end()) {
+    it = searchByName(name);
+    if (it == end()) {
+      foreach (const QByteArray& id,
+               getDisplayNamesOfIds().keys(name.toLatin1())) {
+        if (!id.isEmpty()) {
+          it = searchByName(QString::fromLatin1(id));
+          if (it != end()) {
+            break;
+          }
+        }
       }
     }
   }
+  if (index > 0 && it != end()) {
+    const Frame::ExtendedType extendedType = it->getExtendedType();
+    for (int i = 0; i < index && it != end(); ++i, ++it) {}
+    if (it != end() && !(it->getExtendedType() == extendedType)) {
+      it = end();
+    }
+  }
   return it;
 }
 
@@ -1502,6 +1579,7 @@ QString FrameFormatReplacer::getReplacement(const QString& code) const
 
   if (!name.isNull()) {
     QString lcName(name.toLower());
+    QString fieldName;
     int fieldWidth = lcName == QLatin1String("track") ? 2 : -1;
     if (lcName == QLatin1String("year")) {
       name = QLatin1String("date");
@@ -1515,10 +1593,19 @@ QString FrameFormatReplacer::getReplacement(const QString& code) const
       lcName.truncate(len - 2);
       name.truncate(len - 2);
     }
+    const int dotIndex = name.indexOf(QLatin1Char('.'));
+    if (dotIndex != -1) {
+      fieldName = name.mid(dotIndex + 1);
+      name.truncate(dotIndex);
+    }
 
     FrameCollection::const_iterator it = m_frames.findByName(name);
     if (it != m_frames.end()) {
-      result = it->getValue().trimmed();
+      if (fieldName.isEmpty()) {
+        result = it->getValue().trimmed();
+      } else {
+        result = Frame::getField(*it, fieldName).toString().trimmed();
+      }
       if (result.isNull()) {
         // code was found, but value is empty
         result = QLatin1String("");
