@@ -32,6 +32,7 @@
 #include <QVariant>
 #include <QList>
 #include <set>
+#include "framenotice.h"
 #include "kid3api.h"
 
 /** Generalized frame. */
@@ -320,6 +321,13 @@ public:
      */
     static const char* const* getFieldIdNames();
 
+    /**
+     * Get field ID from field name.
+     * @param fieldName name of field, can be English or translated
+     * @return field ID, ID_NoField if not found.
+     */
+    static FieldId getFieldId(const QString& fieldName);
+
     /**
      * Get a translated string for a text encoding.
      *
@@ -597,6 +605,12 @@ public:
    */
   void setDifferent() { m_value = differentRepresentation(); }
 
+  /**
+   * Get warning notice if frame is marked.
+   * @return notice.
+   */
+  FrameNotice getNotice() const { return m_marked; }
+
   /**
    * Check if frame is marked.
    * @return true if marked.
@@ -604,10 +618,10 @@ public:
   bool isMarked() const { return m_marked; }
 
   /**
-   * Mark frame
-   * @param marked true to mark, false to clear mark
+   * Mark frame.
+   * @param notice warning notice
    */
-  void setMarked(bool marked) { m_marked = marked; }
+  void setMarked(FrameNotice notice) { m_marked = notice; }
 
   /**
    * Check if value is changed.
@@ -716,6 +730,18 @@ public:
    */
   static bool setField(Frame& frame, FieldId id, const QVariant& value);
 
+  /**
+   * Set value of a field.
+   *
+   * @param frame frame to set
+   * @param fieldName name of field, can be English or translated
+   * @param value field value
+   *
+   * @return true if field found and set.
+   */
+  static bool setField(Frame& frame, const QString& fieldName,
+                       const QVariant& value);
+
   /**
    * Get value of a field.
    *
@@ -726,6 +752,16 @@ public:
    */
   static QVariant getField(const Frame& frame, FieldId id);
 
+  /**
+   * Get value of a field.
+   *
+   * @param frame frame to get
+   * @param fieldName name of field, can be English or translated
+   *
+   * @return field value, invalid if not found.
+   */
+  static QVariant getField(const Frame& frame, const QString& fieldName);
+
   /**
    * Get type of frame from English name.
    *
@@ -772,8 +808,8 @@ private:
   int m_index;
   QString m_value;
   FieldList m_fieldList;
+  FrameNotice m_marked;
   bool m_valueChanged;
-  bool m_marked;
 };
 
 /** Filter to enable a subset of frame types. */
@@ -906,10 +942,11 @@ public:
    * @param name  the name of the frame to find, if the exact name is not
    *              found, a case-insensitive search for the first name
    *              starting with this string is performed
+   * @param index 0 for first frame with @a name, 1 for second, etc.
    *
    * @return iterator or end() if not found.
    */
-  const_iterator findByName(const QString& name) const;
+  const_iterator findByName(const QString& name, int index = 0) const;
 
   /**
    * Find a frame by type or name.
