@@ -30,6 +30,7 @@
 #include <QVector>
 #include <QString>
 #include <QSet>
+#include <QUrl>
 #include "frame.h"
 #include "taggedfile.h"
 #include "kid3api.h"
@@ -39,15 +40,6 @@
  */
 class KID3_CORE_EXPORT TrackData : public FrameCollection {
 public:
-  /** Tag version contained in track data. */
-  enum TagVersion {
-    TagNone = 0, /**< Empty or imported and not from a tag */
-    TagV1 = 1,   /**< Tag 1 */
-    TagV2 = 2,   /**< Tag 2 */
-    /** Tag 1 and 2 or merged from tag 2 and tag 1 (where tag 2 is not set) */
-    TagV2V1 = TagV1 | TagV2
-  };
-
   /**
    * Constructor.
    */
@@ -61,7 +53,7 @@ public:
    * @param taggedFile tagged file providing track data
    * @param tagVersion source of frames
    */
-  TrackData(TaggedFile& taggedFile, TagVersion tagVersion);
+  TrackData(TaggedFile& taggedFile, Frame::TagVersion tagVersion);
 
   /**
    * Get duration of file.
@@ -98,22 +90,14 @@ public:
   int getTotalNumberOfTracksInDir() const;
 
   /**
-   * Get the format of tag 1.
+   * Get the tag format.
    *
-   * @return string describing format of tag 1,
+   * @param tagNr tag number
+   * @return string describing format of tag,
    *         e.g. "ID3v1.1", "ID3v2.3", "Vorbis", "APE",
    *         QString::null if unknown.
    */
-  QString getTagFormatV1() const;
-
-  /**
-   * Get the format of tag 2.
-   *
-   * @return string describing format of tag 2,
-   *         e.g. "ID3v2.3", "Vorbis", "APE",
-   *         QString::null if unknown.
-   */
-  QString getTagFormatV2() const;
+  QString getTagFormat(Frame::TagNumber tagNr) const;
 
   /**
    * Get detail info.
@@ -175,15 +159,6 @@ public:
    */
   static QString getFormatToolTip(bool onlyRows = false);
 
-  /**
-   * Cast a mask of tag version bits to a TagVersion enum.
-   * @param tagMask tag mask (bit 0 for tag 1, bit 1 for tag 2)
-   * @return tag version enum value.
-   */
-  static TagVersion tagVersionCast(int tagMask) {
-    return static_cast<TagVersion>(tagMask & 3);
-  }
-
 private:
   QPersistentModelIndex m_taggedFileIndex;
 };
@@ -206,7 +181,7 @@ public:
    * @param taggedFile tagged file providing track data
    * @param tagVersion source of frames
    */
-  ImportTrackData(TaggedFile& taggedFile, TagVersion tagVersion) :
+  ImportTrackData(TaggedFile& taggedFile, Frame::TagVersion tagVersion) :
     TrackData(taggedFile, tagVersion), m_importDuration(0), m_enabled(true) {}
 
   /**
@@ -279,22 +254,23 @@ public:
   QString getAlbum() const;
 
   /**
-   * Check if tag 1 is supported in the first track.
-   * @return true if tag 1 is supported.
+   * Check if tag is supported in the first track.
+   * @param tagNr tag number
+   * @return true if tag is supported.
    */
-  bool isTagV1Supported() const;
+  bool isTagSupported(Frame::TagNumber tagNr) const;
 
   /**
    * Get cover art URL.
    * @return cover art URL.
    */
-  QString getCoverArtUrl() const { return m_coverArtUrl; }
+  QUrl getCoverArtUrl() const { return m_coverArtUrl; }
 
   /**
    * Set cover art URL.
    * @param coverArtUrl cover art URL
    */
-  void setCoverArtUrl(const QString& coverArtUrl) { m_coverArtUrl = coverArtUrl; }
+  void setCoverArtUrl(const QUrl& coverArtUrl) { m_coverArtUrl = coverArtUrl; }
 
   /**
    * Read the tags from the files.
@@ -302,7 +278,7 @@ public:
    *
    * @param tagVersion tag version to read
    */
-  void readTags(ImportTrackData::TagVersion tagVersion);
+  void readTags(Frame::TagVersion tagVersion);
 
 #ifndef QT_NO_DEBUG
   /**
@@ -319,7 +295,7 @@ private:
    */
   QString getFrame(Frame::Type type) const;
 
-  QString m_coverArtUrl;
+  QUrl m_coverArtUrl;
 };
 
 
