@@ -136,6 +136,10 @@ private:
   QLineEdit* m_coverFileNameLineEdit;
   /** File list name filter combo box */
   QComboBox* m_nameFilterComboBox;
+  /** Include folders lineedit */
+  QLineEdit* m_includeFoldersLineEdit;
+  /** Exclude folders lineedit */
+  QLineEdit* m_excludeFoldersLineEdit;
   /** File text encoding combo box */
   QComboBox* m_fileTextEncodingComboBox;
   /** Mark truncated fields checkbox */
@@ -154,6 +158,10 @@ private:
   QSpinBox* m_maximumPictureSizeSpinBox;
   /** Genre as text instead of numeric string checkbox */
   QCheckBox* m_genreNotNumericCheckBox;
+  /** WAV files with lowercase id3 chunk checkbox */
+  QCheckBox* m_lowercaseId3ChunkCheckBox;
+  /** Mark standard violations check box */
+  QCheckBox* m_markStandardViolationsCheckBox;
   /** ID3v2 text encoding combo box */
   QComboBox* m_textEncodingComboBox;
   /** ID3v2 version combo box */
@@ -170,6 +178,8 @@ private:
   QStringListModel* m_genresEditModel;
   /** Model with standard tags selection */
   QStandardItemModel* m_quickAccessTagsModel;
+  /** Track field name combo box */
+  QComboBox* m_trackNameComboBox;
   /** Play on double click checkbox */
   QCheckBox* m_playOnDoubleClickCheckBox;
   /** Commands table */
