@@ -31,6 +31,7 @@
 #include <QTextEdit>
 #include "filefilter.h"
 
+class QGroupBox;
 class QPushButton;
 class FormatListEdit;
 
@@ -65,6 +66,11 @@ public:
    */
   void showInformation(const QString& text) { m_edit->append(text); }
 
+  /**
+   * Abort filter operation.
+   */
+  void abort() { m_fileFilter.abort(); }
+
 signals:
   /**
    * Is triggered when the selected @a filter has to be applied.
@@ -108,6 +114,8 @@ private:
    */
   void setAbortButton(bool enableAbort);
 
+  /** Preview group box */
+  QGroupBox* m_previewBox;
   /** Text editor */
   QTextEdit* m_edit;
   /** format editor */
