@@ -62,7 +62,7 @@ public:
    *
    * @return TagV1, TagV2 or TagV2V1 if ID3v1, ID2v2 or both are destination
    */
-  TrackData::TagVersion getDestination() const;
+  Frame::TagVersion getDestination() const;
 
   /**
    * Set the total number of tracks.
@@ -81,6 +81,18 @@ public:
    */
   int getTotalNumberOfTracks(bool* enable) const;
 
+  /**
+   * Check if track numbering is enabled.
+   * @return true if enabled.
+   */
+  bool isTrackNumberingEnabled() const;
+
+  /**
+   * Check if counter has to be reset for each directory.
+   * @return true if enabled.
+   */
+  bool isDirectoryCounterResetEnabled() const;
+
 private slots:
   /**
    * Save the local settings to the configuration.
@@ -93,10 +105,14 @@ private slots:
   void showHelp();
 
 private:
+  /** check box to enable track numbering */
+  QCheckBox* m_numberTracksCheckBox;
   /** spinbox with starting track number */
   QSpinBox* m_trackSpinBox;
   /** combobox with destination */
   QComboBox* m_destComboBox;
+  /** checkbox to reset counter for each directory*/
+  QCheckBox* m_resetCounterCheckBox;
   /** total number of tracks checkbox */
   QCheckBox* m_totalNumTracksCheckBox;
   /** spinbox with total number of tracks */
