@@ -28,6 +28,7 @@
 #define FILELIST_H
 
 #include <QList>
+#include <QMap>
 #include "configurabletreeview.h"
 #include "config.h"
 #include "kid3api.h"
@@ -60,45 +61,6 @@ public:
    */
   virtual QSize sizeHint() const;
 
-  /**
-   * Fill the filelist with the files found in a directory.
-   *
-   * @param dirIndex index of directory in file proxy model
-   * @param fileIndexes indexes of files to select in file proxy model
-   * (optional, else empty)
-   *
-   * @return false if name is not directory path, else true.
-   */
-  bool readDir(const QPersistentModelIndex& dirIndex,
-               const QList<QPersistentModelIndex>& fileIndexes =
-                 QList<QPersistentModelIndex>());
-
-  /**
-   * Get the stored current selection.
-   * @return stored selection.
-   */
-  const QList<QPersistentModelIndex>& getCurrentSelection() const {
-    return m_currentSelection;
-  }
-
-  /**
-   * Clear the stored current selection.
-   */
-  void clearCurrentSelection() { m_currentSelection.clear(); }
-
-  /**
-   * Update the stored current selection with the list of all selected items.
-   */
-  void updateCurrentSelection();
-
-  /**
-   * Get current index or root index if current index is invalid.
-   * @return current index, root index if not valid.
-   */
-  QModelIndex currentOrRootIndex() const {
-    return currentIndex().isValid() ? currentIndex() : rootIndex();
-  }
-
   /**
    * Set rename action.
    * @param action rename action
@@ -111,6 +73,27 @@ public:
    */
   void setDeleteAction(QAction* action);
 
+public slots:
+  /**
+   * Init the user actions for the context menu.
+   */
+  void initUserActions();
+
+signals:
+  /**
+   * Emitted when a user action is added.
+   * @param name name of action
+   * @param action action added
+   */
+  void userActionAdded(const QString& name, QAction* action);
+
+  /**
+   * Emitted when a user action is removed.
+   * @param name name of action
+   * @param action action removed
+   */
+  void userActionRemoved(const QString& name, QAction* action);
+
 private slots:
   /**
    * Display a context menu with operations for selected files.
@@ -130,9 +113,9 @@ private slots:
   /**
    * Execute a context menu action.
    *
-   * @param action action of selected menu
+   * @param action action of selected menu, 0 to use sender() action
    */
-  void executeAction(QAction* action);
+  void executeAction(QAction* action = 0);
 
   /**
    * Display a custom context menu with operations for selected files.
@@ -188,10 +171,10 @@ private:
 
   /** Process for context menu commands */
   ExternalProcess* m_process;
-  QList<QPersistentModelIndex> m_currentSelection;
   BaseMainWindowImpl* m_mainWin;
   QAction* m_renameAction;
   QAction* m_deleteAction;
+  QMap<QString, QAction*> m_userActions;
 };
 
 #endif // FILELIST_H
