@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 8 Apr 2003
  *
- * Copyright (C) 2003-2014  Urs Fleisch
+ * Copyright (C) 2003-2017  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -31,6 +31,7 @@
 #include <QSpinBox>
 #include <QLayout>
 #include <QToolTip>
+#include <QStackedWidget>
 #include <QSplitter>
 #include <QDir>
 #include <QFrame>
@@ -181,7 +182,9 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
   setAcceptDrops(true);
   setWindowTitle(tr("Kid3"));
 
-  m_vSplitter = new QSplitter(Qt::Vertical, this);
+  m_leftSideWidget = new QStackedWidget(this);
+  m_vSplitter = new QSplitter(Qt::Vertical);
+  m_leftSideWidget->addWidget(m_vSplitter);
   m_fileListBox = new FileList(m_vSplitter, m_mainWin);
   FileProxyModel* fileProxyModel = m_app->getFileProxyModel();
   int iconHeight = (((fontMetrics().height() - 1) / 16) + 1) * 16;
@@ -202,6 +205,8 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
           this, SLOT(setFileRootIndex(QModelIndex)));
   connect(m_app, SIGNAL(dirRootIndexChanged(QModelIndex)),
           this, SLOT(setDirRootIndex(QModelIndex)));
+  connect(m_app, SIGNAL(directoryOpened()),
+          this, SLOT(onFirstDirectoryOpened()));
 
   m_rightHalfVBox = new QWidget;
   QScrollArea* scrollView = new QScrollArea(this);
@@ -705,6 +710,24 @@ void Kid3Form::onFormatFromFilenameEditTextChanged(const QString& text)
   FileConfig::instance().setFromFilenameFormat(text);
 }
 
+/**
+ * Update sorting after directory is opened for the first time.
+ * The sort order of the file list is not correct if it is not explicitly
+ * sorted the first time.
+ */
+void Kid3Form::onFirstDirectoryOpened()
+{
+  // Only call this once.
+  disconnect(m_app, SIGNAL(directoryOpened()),
+             this, SLOT(onFirstDirectoryOpened()));
+  const GuiConfig& guiCfg = GuiConfig::instance();
+  m_app->getFileProxyModel()->sort(guiCfg.fileListSortColumn(),
+                                   guiCfg.fileListSortOrder());
+  foreach (int column, guiCfg.fileListVisibleColumns()) {
+    m_fileListBox->resizeColumnToContents(column);
+  }
+}
+
 /**
  * Hide or show picture.
  *
@@ -903,13 +926,14 @@ void Kid3Form::deselectAllFiles()
  * Set the next file as the current file.
  *
  * @param select true to select the file
+ * @param onlyTaggedFiles only consider tagged files
  *
  * @return true if a next file exists.
  */
-bool Kid3Form::nextFile(bool select)
+bool Kid3Form::nextFile(bool select, bool onlyTaggedFiles)
 {
   FrameTable* editingFrameTable = getEditingFrameTable();
-  bool ok = m_app->nextFile(select);
+  bool ok = m_app->nextFile(select, onlyTaggedFiles);
   if (ok && editingFrameTable) {
     editingFrameTable->edit(editingFrameTable->currentIndex());
   }
@@ -920,13 +944,14 @@ bool Kid3Form::nextFile(bool select)
  * Set the previous file as the current file.
  *
  * @param select true to select the file
+ * @param onlyTaggedFiles only consider tagged files
  *
  * @return true if a previous file exists.
  */
-bool Kid3Form::previousFile(bool select)
+bool Kid3Form::previousFile(bool select, bool onlyTaggedFiles)
 {
   FrameTable* editingFrameTable = getEditingFrameTable();
-  bool ok = m_app->previousFile(select);
+  bool ok = m_app->previousFile(select, onlyTaggedFiles);
   if (ok && editingFrameTable) {
     editingFrameTable->edit(editingFrameTable->currentIndex());
   }
@@ -975,3 +1000,25 @@ void Kid3Form::setDirRootIndex(const QModelIndex& index)
     m_dirListBox->setRootIndex(index);
   }
 }
+
+/**
+ * Set a widget to be displayed at the left side instead of the file lists.
+ * @param widget widget to be shown at the left side
+ */
+void Kid3Form::setLeftSideWidget(QWidget* widget)
+{
+  int idx = m_leftSideWidget->addWidget(widget);
+  m_leftSideWidget->setCurrentIndex(idx);
+}
+
+/**
+ * Remove widget set with setLeftSideWidget().
+ *
+ * The widget will not be deleted.
+ *
+ * @param widget widget to be removed
+ */
+void Kid3Form::removeLeftSideWidget(QWidget* widget)
+{
+  m_leftSideWidget->removeWidget(widget);
+}
