@@ -25,21 +25,54 @@
  */
 
 #include "picturelabel.h"
+#include <QLabel>
+#include <QVBoxLayout>
 #include <QHash>
 #include <QByteArray>
 #include <QPixmap>
 #include <QCoreApplication>
 
+namespace {
+
+class PictureLabelIntern : public QLabel {
+public:
+  explicit PictureLabelIntern(QWidget* parent = 0);
+  virtual ~PictureLabelIntern();
+  virtual int heightForWidth(int w) const;
+};
+
+PictureLabelIntern::PictureLabelIntern(QWidget* parent) : QLabel(parent)
+{
+  setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
+  setWordWrap(true);
+}
+
+PictureLabelIntern::~PictureLabelIntern()
+{
+}
+
+int PictureLabelIntern::heightForWidth(int w) const
+{
+  return w;
+}
+
+}
+
 /**
  * Constructor.
  *
  * @param parent parent widget
  */
-PictureLabel::PictureLabel(QWidget* parent) : QLabel(parent), m_pixmapHash(0)
+PictureLabel::PictureLabel(QWidget* parent) : QWidget(parent), m_pixmapHash(0)
 {
   setObjectName(QLatin1String("PictureLabel"));
-  setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
-  setWordWrap(true);
+  QVBoxLayout* layout = new QVBoxLayout(this);
+  layout->setContentsMargins(0, 0, 0, 0);
+  m_pictureLabel = new PictureLabelIntern;
+  layout->addWidget(m_pictureLabel);
+  m_sizeLabel = new QLabel;
+  m_sizeLabel->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
+  layout->addWidget(m_sizeLabel);
   clearPicture();
 }
 
@@ -50,44 +83,39 @@ PictureLabel::~PictureLabel()
 {
 }
 
-/**
- * Get preferred height for a given width.
- * @return height.
- */
-int PictureLabel::heightForWidth(int w) const
-{
-  return w;
-}
-
 /**
  * Clear picture.
  */
 void PictureLabel::clearPicture()
 {
   const char* const msg = QT_TRANSLATE_NOOP("@default", "Drag album\nartwork\nhere");
-  setText(QCoreApplication::translate("@default", msg));
+  m_pictureLabel->setText(QCoreApplication::translate("@default", msg));
+  m_sizeLabel->clear();
 }
 
 /**
  * Set picture data.
  *
- * @param data picture data, 0 if no picture is available
+ * @param data picture data, empty if no picture is available
  */
-void PictureLabel::setData(const QByteArray* data)
+void PictureLabel::setData(const QByteArray& data)
 {
-  if (data && !data->isEmpty()) {
-    uint hash = qHash(*data);
-    if (pixmap() && hash == m_pixmapHash)
+  if (!data.isEmpty()) {
+    uint hash = qHash(data);
+    if (m_pictureLabel->pixmap() && hash == m_pixmapHash)
       return; // keep existing pixmap
 
     // creating new pixmap
     QPixmap pm;
-    if (pm.loadFromData(*data)) {
-      QPixmap scaledPm = pm.scaled(width(), height(), Qt::KeepAspectRatio);
+    if (pm.loadFromData(data)) {
+      int dimension = m_pictureLabel->width();
+      QPixmap scaledPm = pm.scaled(dimension, dimension, Qt::KeepAspectRatio);
       if (!scaledPm.isNull()) {
         m_pixmapHash = hash;
-        setContentsMargins(0, 0, 0, 0);
-        setPixmap(scaledPm);
+        m_pictureLabel->setContentsMargins(0, 0, 0, 0);
+        m_pictureLabel->setPixmap(scaledPm);
+        m_sizeLabel->setText(QString::number(pm.width()) + QLatin1Char('x') +
+                             QString::number(pm.height()));
         return;
       }
     }
