@@ -42,11 +42,13 @@
 #include <QClipboard>
 #include <QMimeData>
 #include "config.h"
+#include "fileconfig.h"
 #include "timeeventmodel.h"
 #include "timestampdelegate.h"
 #include "eventcodedelegate.h"
 #include "kid3application.h"
 #include "audioplayer.h"
+#include "contexthelp.h"
 #include "iplatformtools.h"
 
 /** Table to edit time events. */
@@ -87,15 +89,17 @@ void TimeEventTableView::keyPressEvent(QKeyEvent* event)
  * @param parent parent widget
  * @param field  field containing binary data
  * @param taggedFile tagged file
+ * @param tagNr tag number
  */
 TimeEventEditor::TimeEventEditor(IPlatformTools* platformTools,
                                  Kid3Application* app,
                                  QWidget* parent, const Frame::Field& field,
-                                 const TaggedFile* taggedFile) :
+                                 const TaggedFile* taggedFile,
+                                 Frame::TagNumber tagNr) :
   QWidget(parent),
   m_platformTools(platformTools), m_app(app), m_eventCodeDelegate(0),
-  m_model(0), m_taggedFile(taggedFile), m_byteArray(field.m_value.toByteArray()),
-  m_fileIsPlayed(false)
+  m_model(0), m_taggedFile(taggedFile), m_tagNr(tagNr),
+  m_byteArray(field.m_value.toByteArray()), m_fileIsPlayed(false)
 {
   setObjectName(QLatin1String("TimeEventEditor"));
   QVBoxLayout* vlayout = new QVBoxLayout(this);
@@ -113,18 +117,22 @@ TimeEventEditor::TimeEventEditor(IPlatformTools* platformTools,
   importButton->setAutoDefault(false);
   QPushButton* exportButton = new QPushButton(tr("&Export..."), this);
   exportButton->setAutoDefault(false);
+  QPushButton* helpButton = new QPushButton(tr("Help"), this);
+  helpButton->setAutoDefault(false);
   buttonLayout->setContentsMargins(0, 0, 0, 0);
   buttonLayout->addWidget(addButton);
   buttonLayout->addWidget(deleteButton);
   buttonLayout->addWidget(clipButton);
   buttonLayout->addWidget(importButton);
   buttonLayout->addWidget(exportButton);
+  buttonLayout->addWidget(helpButton);
   buttonLayout->addStretch();
   connect(addButton, SIGNAL(clicked()), this, SLOT(addItem()));
   connect(deleteButton, SIGNAL(clicked()), this, SLOT(deleteRows()));
   connect(clipButton, SIGNAL(clicked()), this, SLOT(clipData()));
   connect(importButton, SIGNAL(clicked()), this, SLOT(importData()));
   connect(exportButton, SIGNAL(clicked()), this, SLOT(exportData()));
+  connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
   vlayout->addLayout(buttonLayout);
   m_tableView = new TimeEventTableView;
   m_tableView->verticalHeader()->hide();
@@ -301,9 +309,22 @@ void TimeEventEditor::exportData()
     QFile file(saveFileName);
     if (file.open(QIODevice::WriteOnly)) {
       QTextStream stream(&file);
-      m_model->toLrcFile(stream, m_taggedFile->getTitleV2(),
-                                 m_taggedFile->getArtistV2(),
-                                 m_taggedFile->getAlbumV2());
+      QString codecName = FileConfig::instance().textEncoding();
+      if (codecName != QLatin1String("System")) {
+        stream.setCodec(codecName.toLatin1());
+      }
+      QString title, artist, album;
+      Frame frame;
+      if (m_taggedFile->getFrame(m_tagNr, Frame::FT_Title, frame)) {
+        title = frame.getValue();
+      }
+      if (m_taggedFile->getFrame(m_tagNr, Frame::FT_Artist, frame)) {
+        artist = frame.getValue();
+      }
+      if (m_taggedFile->getFrame(m_tagNr, Frame::FT_Album, frame)) {
+        album = frame.getValue();
+      }
+      m_model->toLrcFile(stream, title, artist, album);
       file.close();
     }
   }
@@ -315,13 +336,13 @@ void TimeEventEditor::exportData()
  */
 QString TimeEventEditor::getLrcNameFilter() const
 {
+  const char* const lyricsStr = QT_TRANSLATE_NOOP("@default", "Lyrics");
+  const char* const allFilesStr = QT_TRANSLATE_NOOP("@default", "All Files");
   return m_platformTools->fileDialogNameFilter(
         QList<QPair<QString, QString> >()
-        << qMakePair(QCoreApplication::translate("@default",
-                         QT_TRANSLATE_NOOP("@default", "Lyrics")),
+        << qMakePair(QCoreApplication::translate("@default", lyricsStr),
                      QString(QLatin1String("*.lrc")))
-        << qMakePair(QCoreApplication::translate("@default",
-                         QT_TRANSLATE_NOOP("@default", "All Files")),
+        << qMakePair(QCoreApplication::translate("@default", allFilesStr),
                      QString(QLatin1Char('*'))));
 }
 
@@ -469,3 +490,11 @@ void TimeEventEditor::onPositionChanged(qint64 position)
                           QAbstractItemView::PositionAtCenter);
   }
 }
+
+/**
+ * Show help.
+ */
+void TimeEventEditor::showHelp()
+{
+  ContextHelp::displayHelp(QLatin1String("synchronized-lyrics"));
+}
