@@ -76,6 +76,9 @@ int TaglibMetadataPlugin::taggedFileFeatures(const QString& key) const
 {
   if (key == TAGGEDFILE_KEY) {
     return TaggedFile::TF_ID3v11 | TaggedFile::TF_ID3v22 |
+#if TAGLIB_VERSION >= 0x010500
+        TaggedFile::TF_OggFlac |
+#endif
 #if TAGLIB_VERSION >= 0x010700
         TaggedFile::TF_OggPictures |
 #endif
@@ -103,7 +106,6 @@ void TaglibMetadataPlugin::initialize(const QString& key)
  * Create a tagged file.
  *
  * @param key tagged file key
- * @param dirName directory name
  * @param fileName filename
  * @param idx model index
  * @param features optional tagged file features (TaggedFile::Feature flags)
@@ -113,7 +115,7 @@ void TaglibMetadataPlugin::initialize(const QString& key)
  */
 TaggedFile* TaglibMetadataPlugin::createTaggedFile(
     const QString& key,
-    const QString& dirName, const QString& fileName,
+    const QString& fileName,
     const QPersistentModelIndex& idx,
     int features)
 {
@@ -151,9 +153,12 @@ TaggedFile* TaglibMetadataPlugin::createTaggedFile(
 #endif
 #if TAGLIB_VERSION >= 0x010900
         || ext == QLatin1String("opus")
+#endif
+#if TAGLIB_VERSION >= 0x010901
+        || ext == QLatin1String(".dsf")
 #endif
         || ext2 == QLatin1String(".wv"))
-      return new TagLibFile(dirName, fileName, idx);
+      return new TagLibFile(idx);
   }
   return 0;
 }
@@ -191,6 +196,9 @@ TaglibMetadataPlugin::supportedFileExtensions(const QString& key) const
 #endif
 #if TAGLIB_VERSION >= 0x010900
       QLatin1String(".opus") <<
+#endif
+#if TAGLIB_VERSION >= 0x010901
+      QLatin1String(".dsf") <<
 #endif
       QLatin1String(".wv");
   }
