@@ -22,7 +22,7 @@ class CliFunctionsTestCase(unittest.TestCase):
         full_help = call_kid3_cli('-h')
         self.assertIn('Available Commands', full_help)
         self.assertRegex(full_help, r'help \[S\]\s+Help')
-        self.assertRegex(full_help, r'^kid3-cli \d\.\d\.\d \(c\) \d{4} Urs Fleisch')
+        self.assertRegex(full_help, r'^kid3-cli (\d\.\d\.\d|git\d{8}) \(c\) \d{4} Urs Fleisch')
         full_help = call_kid3_cli(['-c', 'help'])
         self.assertIn('Available Commands', full_help)
         self.assertRegex(full_help, r'help \[S\]\s+Help')
@@ -193,7 +193,7 @@ class CliFunctionsTestCase(unittest.TestCase):
                  '-c', 'get all 2', mp3path]),
                 'File: MPEG 1 Layer 3 64 kbps 44100 Hz 1 Channels \n'
                 '  Name: test.mp3\n'
-                'Tag 2: ID3v2.4.0\n'
+                'Tag 2: ID3v2.3.0\n'
                 '* Artist                  An Artist\n'
                 '* Album                   An Album\n'
                 '* Comment                 A Comment\n'
@@ -295,6 +295,300 @@ class CliFunctionsTestCase(unittest.TestCase):
             with open(picpath, 'rb') as jpgfh:
                 ba = jpgfh.read()
                 self.assertEqual(ba, jpg_bytes)
+            self.assertEqual(call_kid3_cli(
+                ['-c', 'set POPM 5',
+                 '-c', 'get all 2',
+                 '-c', 'get POPM.Email',
+                 '-c', 'get POPM.Rating',
+                 '-c', 'get POPM.Counter',
+                 '-c', 'set POPM.Email ufleisch@users.sourceforge.net',
+                 '-c', 'set POPM.Rating 4',
+                 '-c', 'set POPM.Counter 3',
+                 '-c', 'get all 2',
+                 '-c', 'get POPM.Email',
+                 '-c', 'get POPM.Rating',
+                 '-c', 'get POPM.Counter',
+                 '-c', 'get POPM', mp3path]),
+                'File: MPEG 1 Layer 3 64 kbps 44100 Hz 1 Channels \n'
+                '  Name: test.mp3\n'
+                'Tag 2: ID3v2.3.0\n'
+                '* Popularimeter  5\n'
+                '\n'
+                '5\n'
+                '0\n'
+                'File: MPEG 1 Layer 3 64 kbps 44100 Hz 1 Channels \n'
+                '  Name: test.mp3\n'
+                'Tag 2: ID3v2.3.0\n'
+                '* Popularimeter  4\n'
+                'ufleisch@users.sourceforge.net\n'
+                '4\n'
+                '3\n'
+                '4\n')
+
+    def test_flac(self):
+        with tempfile.TemporaryDirectory() as tmpdir:
+            flacpath = os.path.join(tmpdir, 'test.flac')
+            jpgpath = os.path.join(tmpdir, 'test.jpg')
+            picpath = os.path.join(tmpdir, 'folder.jpg')
+            create_test_file(flacpath)
+            create_test_file(jpgpath)
+            with open(jpgpath, 'rb') as jpgfh:
+                jpg_bytes = jpgfh.read()
+            self.assertEqual(call_kid3_cli(
+                ['-c', 'get title 2',
+                 '-c', 'get all 2', flacpath]),
+                'File: FLAC 705 kbps 44100 Hz 1 Channels \n'
+                '  Name: test.flac\n')
+            self.assertEqual(call_kid3_cli(
+                ['-c', 'set artist "A first artist"',
+                 '-c', 'set artist[1] "A second artist"',
+                 '-c', 'set album "Album Name"',
+                 '-c', 'set track 4',
+                 '-c', 'set genre "Heavy Metal"',
+                 '-c', 'set date 2017',
+                 '-c', 'set comment[0] "Comment 1"',
+                 '-c', 'set comment[1] "Comment 2"',
+                 '-c', 'set comment[2] "Comment 3"',
+                 '-c', 'set Lyricist "A Lyricist" 2',
+                 '-c', 'set tracktotal 12',
+                 '-c', 'set "disc number" 1',
+                 '-c', 'set DISCTOTAL 2',
+                 '-c', 'set picture:"%s" "Picture Description"' % jpgpath,
+                 '-c', 'get comment[1]',
+                 '-c', 'get comment',
+                 '-c', 'get', flacpath]),
+                 'Comment 2\n'
+                 'Comment 1\n'
+                 'File: FLAC 705 kbps 44100 Hz 1 Channels \n'
+                 '  Name: test.flac\n'
+                 'Tag 2: Vorbis\n'
+                 '* Artist                  A first artist\n'
+                 '* Artist                  A second artist\n'
+                 '* Album                   Album Name\n'
+                 '* Comment                 Comment 1\n'
+                 '* Comment                 Comment 2\n'
+                 '* Comment                 Comment 3\n'
+                 '* Date                    2017\n'
+                 '* Track Number            4\n'
+                 '* Genre                   Heavy Metal\n'
+                 '* Disc Number             1\n'
+                 '* Lyricist                A Lyricist\n'
+                 '* Picture: Cover (front)  Picture Description\n'
+                 '* Total Discs             2\n'
+                 '* Total Tracks            12\n')
+            self.assertEqual(call_kid3_cli(
+                ['-c', 'set artist[1] ""',
+                 '-c', 'set comment[1] "Comment B"',
+                 '-c', 'set comment[0] "Comment A"',
+                 '-c', 'set comment[2] "Comment C"',
+                 '-c', 'set lyricist ""',
+                 '-c', 'set picture[1]:"%s" "Back Cover"' % jpgpath,
+                 '-c', 'set picture[1].picturetype 4',
+                 '-c', 'set picture[0].description "Front Cover"',
+                 '-c', 'get picture[1]:"%s"' % picpath,
+                 '-c', 'get',
+                 '-c', 'remove',
+                 '-c', 'get', flacpath]),
+                 'Back Cover\n'
+                 'File: FLAC 705 kbps 44100 Hz 1 Channels \n'
+                 '  Name: test.flac\n'
+                 'Tag 2: Vorbis\n'
+                 '* Artist                  A first artist\n'
+                 '  Album                   Album Name\n'
+                 '* Comment                 Comment A\n'
+                 '* Comment                 Comment B\n'
+                 '* Comment                 Comment C\n'
+                 '  Date                    2017\n'
+                 '  Track Number            4\n'
+                 '  Genre                   Heavy Metal\n'
+                 '  Disc Number             1\n'
+                 '* Picture: Cover (front)  Front Cover\n'
+                 '* Picture: Cover (back)   Back Cover\n'
+                 '  Total Discs             2\n'
+                 '  Total Tracks            12\n'
+                 'File: FLAC 705 kbps 44100 Hz 1 Channels \n'
+                 '  Name: test.flac\n')
+            with open(picpath, 'rb') as jpgfh:
+                ba = jpgfh.read()
+                self.assertEqual(ba, jpg_bytes)
+
+    def test_frame_selection(self):
+        with tempfile.TemporaryDirectory() as tmpdir:
+            test1path = os.path.join(tmpdir, 'test1.mp3')
+            test2path = os.path.join(tmpdir, 'test2.mp3')
+            create_test_file(test1path)
+            create_test_file(test2path)
+            self.assertEqual(call_kid3_cli(
+                ['-c', 'get all 2', test1path]),
+                'File: MPEG 1 Layer 3 64 kbps 44100 Hz 1 Channels \n'
+                '  Name: test1.mp3\n')
+            self.assertEqual(call_kid3_cli(
+                ['-c', 'get all 2', test2path]),
+                'File: MPEG 1 Layer 3 64 kbps 44100 Hz 1 Channels \n'
+                '  Name: test2.mp3\n')
+            expected = (
+                'Tag 2: \n'
+                '  Title         ≠\n'
+                '  Artist        An Artist\n'
+                '  Album         An Album\n'
+                '  Copyright     ≠\n'
+                '  Disc Number   ≠\n')
+            if sys.platform == 'win32':
+                expected = expected.replace('≠', '?')
+            self.assertEqual(call_kid3_cli(
+                ['-c', 'select all',
+                 '-c', 'set artist "An Artist"',
+                 '-c', 'set album "An Album"',
+                 '-c', 'select none',
+                 '-c', 'select first',
+                 '-c', 'set title "Title 1"',
+                 '-c', 'set discnumber "1/2"',
+                 '-c', 'set copyright "2017 Kid3"',
+                 '-c', 'select next',
+                 '-c', 'set title "Title 2"',
+                 '-c', 'save',
+                 '-c', 'select all',
+                 '-c', 'get', tmpdir]),
+                 expected)
+            self.assertEqual(call_kid3_cli(
+                ['-c', 'select first',
+                 '-c', 'get',
+                 '-c', 'set "*.selected" 0',
+                 '-c', 'set "album.selected" 1',
+                 '-c', 'remove',
+                 '-c', 'get',
+                 '-c', 'revert',
+                 '-c', 'set "*.selected" 0',
+                 '-c', 'set "discnumber.selected" 1',
+                 '-c', 'set "copyright.selected" 1',
+                 '-c', 'copy',
+                 '-c', 'select next',
+                 '-c', 'paste',
+                 '-c', 'get',
+                 '-c', 'revert',
+                 '-c', 'select all',
+                 '-c', 'set "*.selected" 0',
+                 '-c', 'set "discnumber.selected" 1',
+                 '-c', 'paste',
+                 '-c', 'select first',
+                 '-c', 'get',
+                 '-c', 'select next',
+                 '-c', 'get', tmpdir]),
+                 'File: MPEG 1 Layer 3 64 kbps 44100 Hz 1 Channels \n'
+                 '  Name: test1.mp3\n'
+                 'Tag 2: ID3v2.3.0\n'
+                 '  Title         Title 1\n'
+                 '  Artist        An Artist\n'
+                 '  Album         An Album\n'
+                 '  Copyright     2017 Kid3\n'
+                 '  Disc Number   1/2\n'
+                 'File: MPEG 1 Layer 3 64 kbps 44100 Hz 1 Channels \n'
+                 '  Name: test1.mp3\n'
+                 'Tag 2: ID3v2.3.0\n'
+                 '  Title         Title 1\n'
+                 '  Artist        An Artist\n'
+                 '  Copyright     2017 Kid3\n'
+                 '  Disc Number   1/2\n'
+                 'File: MPEG 1 Layer 3 64 kbps 44100 Hz 1 Channels \n'
+                 '  Name: test2.mp3\n'
+                 'Tag 2: ID3v2.3.0\n'
+                 '  Title         Title 2\n'
+                 '  Artist        An Artist\n'
+                 '  Album         An Album\n'
+                 '* Copyright     2017 Kid3\n'
+                 '* Disc Number   1/2\n'
+                 'File: MPEG 1 Layer 3 64 kbps 44100 Hz 1 Channels \n'
+                 '  Name: test1.mp3\n'
+                 'Tag 2: ID3v2.3.0\n'
+                 '  Title         Title 1\n'
+                 '  Artist        An Artist\n'
+                 '  Album         An Album\n'
+                 '  Copyright     2017 Kid3\n'
+                 '  Disc Number   1/2\n'
+                 'File: MPEG 1 Layer 3 64 kbps 44100 Hz 1 Channels \n'
+                 '  Name: test2.mp3\n'
+                 'Tag 2: ID3v2.3.0\n'
+                 '  Title         Title 2\n'
+                 '  Artist        An Artist\n'
+                 '  Album         An Album\n'
+                 '* Disc Number   1/2\n')
+
+    def test_riff_info(self):
+        with tempfile.TemporaryDirectory() as tmpdir:
+            wavpath = os.path.join(tmpdir, 'test.wav')
+            create_test_file(wavpath)
+            with open(wavpath, 'rb') as wavfh:
+                empty_wav_bytes = wavfh.read()
+            self.assertEqual(call_kid3_cli(
+                ['-c', 'get title 3',
+                 '-c', 'get all 3', wavpath]),
+                'File: WAV 44100 Hz 2 Channels \n'
+                '  Name: test.wav\n')
+            self.assertEqual(call_kid3_cli(
+                ['-c', 'set artist "An Artist" 3',
+                 '-c', 'set album "An Album" 3',
+                 '-c', 'set tracknumber 2 3',
+                 '-c', 'set genre "Heavy Metal" 3',
+                 '-c', 'set date 2017 3',
+                 '-c', 'set comment "A Comment" 3',
+                 '-c', 'set bpm "120" 3',
+                 '-c', 'set comment "A Comment" 3',
+                 '-c', 'get all 3', wavpath]),
+                'File: WAV 44100 Hz 2 Channels \n'
+                '  Name: test.wav\n'
+                'Tag 3: RIFF INFO\n'
+                '* Artist        An Artist\n'
+                '* Album         An Album\n'
+                '* Comment       A Comment\n'
+                '* Date          2017\n'
+                '* Track Number  2\n'
+                '* Genre         Heavy Metal\n'
+                '* BPM           120\n')
+            self.assertEqual(call_kid3_cli(
+                ['-c', 'copy 3',
+                 '-c', 'remove 3',
+                 '-c', 'get all 3',
+                 '-c', 'paste 3',
+                 '-c', 'get all 3',
+                 '-c', 'set tracknumber 6 3',
+                 '-c', 'get all 3',
+                 '-c', 'set comment "" 3',
+                 '-c', 'get all 3',
+                 '-c', 'remove 3', wavpath]),
+                'File: WAV 44100 Hz 2 Channels \n'
+                '  Name: test.wav\n'
+                'File: WAV 44100 Hz 2 Channels \n'
+                '  Name: test.wav\n'
+                'Tag 3: RIFF INFO\n'
+                '* Artist        An Artist\n'
+                '* Album         An Album\n'
+                '* Comment       A Comment\n'
+                '* Date          2017\n'
+                '* Track Number  2\n'
+                '* Genre         Heavy Metal\n'
+                '* BPM           120\n'
+                'File: WAV 44100 Hz 2 Channels \n'
+                '  Name: test.wav\n'
+                'Tag 3: RIFF INFO\n'
+                '* Artist        An Artist\n'
+                '* Album         An Album\n'
+                '* Comment       A Comment\n'
+                '* Date          2017\n'
+                '* Track Number  6\n'
+                '* Genre         Heavy Metal\n'
+                '* BPM           120\n'
+                'File: WAV 44100 Hz 2 Channels \n'
+                '  Name: test.wav\n'
+                'Tag 3: RIFF INFO\n'
+                '* Artist        An Artist\n'
+                '* Album         An Album\n'
+                '* Date          2017\n'
+                '* Track Number  6\n'
+                '* Genre         Heavy Metal\n'
+                '* BPM           120\n')
+            with open(wavpath, 'rb') as wavfh:
+                ba = wavfh.read()
+                self.assertEqual(ba, empty_wav_bytes)
 
     def test_multiple_files(self):
         with tempfile.TemporaryDirectory() as tmpdir:
@@ -384,7 +678,7 @@ class CliFunctionsTestCase(unittest.TestCase):
                 '  Genre         Metal\n'
                 'File: WAV 44100 Hz 2 Channels \n'
                 '  Name: track05.wav\n'
-                'Tag 2: ID3v2.4.0\n'
+                'Tag 2: ID3v2.3.0\n'
                 '  Title         Hail And Kill\n'
                 '  Artist        Manowar\n'
                 '  Album         Kings Of Metal\n'
@@ -486,7 +780,7 @@ class CliFunctionsTestCase(unittest.TestCase):
                 lines[2:],
                 ['- 01 Wheels Of Fire.m4a', '- 02 Kings Of Metal.flac',
                  '- 03 Heart Of Steel.spx', '+ 05 The Crown And The Ring (Lament Of The Kings).mp3',
-                 '- 06 Kingdom Come.ape', '- 08 Hail And Kill.wav', '- 09 The Warriors Prayer.opus',
+                 '- 06 Kingdom Come.ape', '+ 08 Hail And Kill.wav', '- 09 The Warriors Prayer.opus',
                  '- 10 Blood Of The Kings.aiff', 'Finished'])
             call_kid3_cli(['-c', 'renamedir "%{artist} - [%{year}] %{album}" "create"', tmpdir])
             new_dirname = 'Manowar - [1988] Kings Of Metal'
